@@ -3,7 +3,7 @@
  * Copyright: 1990, N. Dessipris, based on im_powtra()
  * Author: Nicos Dessipris
  * Written on: 02/05/1990
- * Modified on: 
+ * Modified on:
  * 5/5/93 JC
  *	- adapted from im_lintra to work with partial images
  *	- incorrect implementation of complex logs removed
@@ -29,28 +29,28 @@
 
 /*
 
-    Copyright (C) 1991-2005 The National Gallery
+	Copyright (C) 1991-2005 The National Gallery
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
+	This library is free software; you can redistribute it and/or
+	modify it under the terms of the GNU Lesser General Public
+	License as published by the Free Software Foundation; either
+	version 2.1 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
-    Lesser General Public License for more details.
+	This library is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+	Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA
+	You should have received a copy of the GNU Lesser General Public
+	License along with this library; if not, write to the Free Software
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+	02110-1301  USA
 
  */
 
 /*
 
-    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
+	These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
 
  */
 
@@ -80,112 +80,141 @@ typedef struct _VipsMath {
 
 typedef VipsUnaryClass VipsMathClass;
 
-G_DEFINE_TYPE( VipsMath, vips_math, VIPS_TYPE_UNARY );
+G_DEFINE_TYPE(VipsMath, vips_math, VIPS_TYPE_UNARY);
 
 static int
-vips_math_build( VipsObject *object )
+vips_math_build(VipsObject *object)
 {
-	VipsObjectClass *class = VIPS_OBJECT_GET_CLASS( object );
+	VipsObjectClass *class = VIPS_OBJECT_GET_CLASS(object);
 	VipsUnary *unary = (VipsUnary *) object;
 
-	if( unary->in &&
-		vips_check_noncomplex( class->nickname, unary->in ) )
-		return( -1 );
+	if (unary->in &&
+		vips_check_noncomplex(class->nickname, unary->in))
+		return -1;
 
-	if( VIPS_OBJECT_CLASS( vips_math_parent_class )->build( object ) )
-		return( -1 );
+	if (VIPS_OBJECT_CLASS(vips_math_parent_class)->build(object))
+		return -1;
 
-	return( 0 );
+	return 0;
 }
 
-#define LOOP( IN, OUT, OP ) { \
-	IN * restrict p = (IN *) in[0]; \
-	OUT * restrict q = (OUT *) out; \
-	\
-	for( x = 0; x < sz; x++ ) \
-		q[x] = OP( p[x] ); \
-}
+#define LOOP(IN, OUT, OP) \
+	{ \
+		IN *restrict p = (IN *) in[0]; \
+		OUT *restrict q = (OUT *) out; \
+\
+		for (x = 0; x < sz; x++) \
+			q[x] = OP(p[x]); \
+	}
 
-#define SWITCH( OP ) \
-	switch( vips_image_get_format( im ) ) { \
+#define SWITCH(OP) \
+	switch (vips_image_get_format(im)) { \
 	case VIPS_FORMAT_UCHAR: \
-		LOOP( unsigned char, float, OP ); break; \
+		LOOP(unsigned char, float, OP); \
+		break; \
 	case VIPS_FORMAT_CHAR: \
-		LOOP( signed char, float, OP ); break; \
+		LOOP(signed char, float, OP); \
+		break; \
 	case VIPS_FORMAT_USHORT: \
-		LOOP( unsigned short, float, OP ); break; \
+		LOOP(unsigned short, float, OP); \
+		break; \
 	case VIPS_FORMAT_SHORT: \
-		LOOP( signed short, float, OP ); break; \
+		LOOP(signed short, float, OP); \
+		break; \
 	case VIPS_FORMAT_UINT: \
-		LOOP( unsigned int, float, OP ); break; \
+		LOOP(unsigned int, float, OP); \
+		break; \
 	case VIPS_FORMAT_INT: \
-		LOOP( signed int, float, OP ); break; \
+		LOOP(signed int, float, OP); \
+		break; \
 	case VIPS_FORMAT_FLOAT: \
-		LOOP( float, float, OP ); break; \
+		LOOP(float, float, OP); \
+		break; \
 	case VIPS_FORMAT_DOUBLE: \
-		LOOP( double, double, OP ); break;\
- 	\
+		LOOP(double, double, OP); \
+		break; \
+\
 	default: \
 		g_assert_not_reached(); \
-	} 
-
-/* If there's asinh, assume we have the other two as well.
- */
-#if HAVE_ASINH
-  #define ASINH( X ) (asinh( X ))
-  #define ACOSH( X ) (acosh( X ))
-  #define ATANH( X ) (atanh( X ))
-#else
-  #define ASINH( X ) (LOGZ( (X) + sqrt( (X) * (X) + 1.0 ) ))
-  #define ACOSH( X ) (LOGZ( (X) + sqrt( (X) * (X) - 1.0 ) ))
-  #define ATANH( X ) (0.5 * LOGZ( (1.0 + (X)) / (1.0 - (X)) ))
-#endif
+	}
 
 /* sin/cos/tan in degrees.
  */
-#define DSIN( X ) (sin( VIPS_RAD( X ) ))
-#define DCOS( X ) (cos( VIPS_RAD( X ) ))
-#define DTAN( X ) (tan( VIPS_RAD( X ) ))
-#define ADSIN( X ) (VIPS_DEG( asin( X ) ))
-#define ADCOS( X ) (VIPS_DEG( acos( X ) ))
-#define ADTAN( X ) (VIPS_DEG( atan( X ) ))
+#define DSIN(X) (sin(VIPS_RAD(X)))
+#define DCOS(X) (cos(VIPS_RAD(X)))
+#define DTAN(X) (tan(VIPS_RAD(X)))
+#define ADSIN(X) (VIPS_DEG(asin(X)))
+#define ADCOS(X) (VIPS_DEG(acos(X)))
+#define ADTAN(X) (VIPS_DEG(atan(X)))
 
 /* exp10() is a gnu extension, use pow().
  */
-#define EXP10( X ) (pow( 10.0, (X) ))
+#define EXP10(X) (pow(10.0, (X)))
 
 /* Zero-avoiding log, cf. zero-avoiding behaviour of /.
  */
-#define LOGZ( X ) ((X) == 0.0 ? 0.0 : log( X ))
-#define LOGZ10( X ) ((X) == 0.0 ? 0.0 : log10( X ))
+#define LOGZ(X) ((X) == 0.0 ? 0.0 : log(X))
+#define LOGZ10(X) ((X) == 0.0 ? 0.0 : log10(X))
 
 static void
-vips_math_buffer( VipsArithmetic *arithmetic, 
-	VipsPel *out, VipsPel **in, int width )
+vips_math_buffer(VipsArithmetic *arithmetic,
+	VipsPel *out, VipsPel **in, int width)
 {
 	VipsMath *math = (VipsMath *) arithmetic;
 	VipsImage *im = arithmetic->ready[0];
-	const int sz = width * vips_image_get_bands( im );
+	const int sz = width * vips_image_get_bands(im);
 
 	int x;
 
-	switch( math->math ) {
-	case VIPS_OPERATION_MATH_SIN: 	SWITCH( DSIN ); break;
-	case VIPS_OPERATION_MATH_COS: 	SWITCH( DCOS ); break;
-	case VIPS_OPERATION_MATH_TAN: 	SWITCH( DTAN ); break;
-	case VIPS_OPERATION_MATH_ASIN: 	SWITCH( ADSIN ); break;
-	case VIPS_OPERATION_MATH_ACOS: 	SWITCH( ADCOS ); break;
-	case VIPS_OPERATION_MATH_ATAN: 	SWITCH( ADTAN ); break;
-	case VIPS_OPERATION_MATH_SINH: 	SWITCH( sinh ); break;
-	case VIPS_OPERATION_MATH_COSH: 	SWITCH( cosh ); break;
-	case VIPS_OPERATION_MATH_TANH: 	SWITCH( tanh ); break;
-	case VIPS_OPERATION_MATH_ASINH:	SWITCH( ASINH ); break;
-	case VIPS_OPERATION_MATH_ACOSH:	SWITCH( ACOSH ); break;
-	case VIPS_OPERATION_MATH_ATANH:	SWITCH( ATANH ); break;
-	case VIPS_OPERATION_MATH_LOG: 	SWITCH( LOGZ ); break;
-	case VIPS_OPERATION_MATH_LOG10:	SWITCH( LOGZ10 ); break;
-	case VIPS_OPERATION_MATH_EXP: 	SWITCH( exp ); break;
-	case VIPS_OPERATION_MATH_EXP10:	SWITCH( EXP10 ); break;
+	switch (math->math) {
+	case VIPS_OPERATION_MATH_SIN:
+		SWITCH(DSIN);
+		break;
+	case VIPS_OPERATION_MATH_COS:
+		SWITCH(DCOS);
+		break;
+	case VIPS_OPERATION_MATH_TAN:
+		SWITCH(DTAN);
+		break;
+	case VIPS_OPERATION_MATH_ASIN:
+		SWITCH(ADSIN);
+		break;
+	case VIPS_OPERATION_MATH_ACOS:
+		SWITCH(ADCOS);
+		break;
+	case VIPS_OPERATION_MATH_ATAN:
+		SWITCH(ADTAN);
+		break;
+	case VIPS_OPERATION_MATH_SINH:
+		SWITCH(sinh);
+		break;
+	case VIPS_OPERATION_MATH_COSH:
+		SWITCH(cosh);
+		break;
+	case VIPS_OPERATION_MATH_TANH:
+		SWITCH(tanh);
+		break;
+	case VIPS_OPERATION_MATH_ASINH:
+		SWITCH(asinh);
+		break;
+	case VIPS_OPERATION_MATH_ACOSH:
+		SWITCH(acosh);
+		break;
+	case VIPS_OPERATION_MATH_ATANH:
+		SWITCH(atanh);
+		break;
+	case VIPS_OPERATION_MATH_LOG:
+		SWITCH(LOGZ);
+		break;
+	case VIPS_OPERATION_MATH_LOG10:
+		SWITCH(LOGZ10);
+		break;
+	case VIPS_OPERATION_MATH_EXP:
+		SWITCH(exp);
+		break;
+	case VIPS_OPERATION_MATH_EXP10:
+		SWITCH(EXP10);
+		break;
 
 	default:
 		g_assert_not_reached();
@@ -211,40 +240,40 @@ static const VipsBandFormat vips_math_format_table[10] = {
 };
 
 static void
-vips_math_class_init( VipsMathClass *class )
+vips_math_class_init(VipsMathClass *class)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS( class );
+	GObjectClass *gobject_class = G_OBJECT_CLASS(class);
 	VipsObjectClass *object_class = (VipsObjectClass *) class;
-	VipsArithmeticClass *aclass = VIPS_ARITHMETIC_CLASS( class );
+	VipsArithmeticClass *aclass = VIPS_ARITHMETIC_CLASS(class);
 
 	gobject_class->set_property = vips_object_set_property;
 	gobject_class->get_property = vips_object_get_property;
 
 	object_class->nickname = "math";
-	object_class->description = _( "apply a math operation to an image" );
+	object_class->description = _("apply a math operation to an image");
 	object_class->build = vips_math_build;
 
 	aclass->process_line = vips_math_buffer;
 
-	vips_arithmetic_set_format_table( aclass, vips_math_format_table ); 
+	vips_arithmetic_set_format_table(aclass, vips_math_format_table);
 
-	VIPS_ARG_ENUM( class, "math", 200, 
-		_( "Operation" ), 
-		_( "Math to perform" ),
+	VIPS_ARG_ENUM(class, "math", 200,
+		_("Operation"),
+		_("Math to perform"),
 		VIPS_ARGUMENT_REQUIRED_INPUT,
-		G_STRUCT_OFFSET( VipsMath, math ),
-		VIPS_TYPE_OPERATION_MATH, VIPS_OPERATION_MATH_SIN ); 
+		G_STRUCT_OFFSET(VipsMath, math),
+		VIPS_TYPE_OPERATION_MATH, VIPS_OPERATION_MATH_SIN);
 }
 
 static void
-vips_math_init( VipsMath *math )
+vips_math_init(VipsMath *math)
 {
 }
 
 static int
-vips_mathv( VipsImage *in, VipsImage **out, VipsOperationMath math, va_list ap )
+vips_mathv(VipsImage *in, VipsImage **out, VipsOperationMath math, va_list ap)
 {
-	return( vips_call_split( "math", ap, in, out, math ) );
+	return vips_call_split("math", ap, in, out, math);
 }
 
 /**
@@ -254,10 +283,10 @@ vips_mathv( VipsImage *in, VipsImage **out, VipsOperationMath math, va_list ap )
  * @math: math operation to perform
  * @...: %NULL-terminated list of optional named arguments
  *
- * Perform various functions in -lm, the maths library, on images. 
+ * Perform various functions in -lm, the maths library, on images.
  *
- * Angles are expressed in degrees. The output type is float unless the 
- * input is double, in which case the output is double.  
+ * Angles are expressed in degrees. The output type is float unless the
+ * input is double, in which case the output is double.
  *
  * Non-complex images only.
  *
@@ -266,16 +295,16 @@ vips_mathv( VipsImage *in, VipsImage **out, VipsOperationMath math, va_list ap )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_math( VipsImage *in, VipsImage **out, VipsOperationMath math, ... )
+vips_math(VipsImage *in, VipsImage **out, VipsOperationMath math, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, math );
-	result = vips_mathv( in, out, math, ap );
-	va_end( ap );
+	va_start(ap, math);
+	result = vips_mathv(in, out, math, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -289,16 +318,16 @@ vips_math( VipsImage *in, VipsImage **out, VipsOperationMath math, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_sin( VipsImage *in, VipsImage **out, ... )
+vips_sin(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_SIN, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_SIN, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -312,16 +341,16 @@ vips_sin( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_cos( VipsImage *in, VipsImage **out, ... )
+vips_cos(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_COS, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_COS, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -335,16 +364,16 @@ vips_cos( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_tan( VipsImage *in, VipsImage **out, ... )
+vips_tan(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_TAN, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_TAN, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -358,16 +387,16 @@ vips_tan( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_asin( VipsImage *in, VipsImage **out, ... )
+vips_asin(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_ASIN, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_ASIN, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -381,16 +410,16 @@ vips_asin( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_acos( VipsImage *in, VipsImage **out, ... )
+vips_acos(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_ACOS, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_ACOS, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -404,16 +433,16 @@ vips_acos( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_atan( VipsImage *in, VipsImage **out, ... )
+vips_atan(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_ATAN, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_ATAN, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -427,16 +456,16 @@ vips_atan( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_sinh( VipsImage *in, VipsImage **out, ... )
+vips_sinh(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_SINH, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_SINH, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -450,16 +479,16 @@ vips_sinh( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_cosh( VipsImage *in, VipsImage **out, ... )
+vips_cosh(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_COSH, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_COSH, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -473,16 +502,16 @@ vips_cosh( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_tanh( VipsImage *in, VipsImage **out, ... )
+vips_tanh(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_TANH, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_TANH, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -496,16 +525,16 @@ vips_tanh( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_asinh( VipsImage *in, VipsImage **out, ... )
+vips_asinh(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_ASINH, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_ASINH, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -519,16 +548,16 @@ vips_asinh( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_acosh( VipsImage *in, VipsImage **out, ... )
+vips_acosh(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_ACOSH, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_ACOSH, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -542,16 +571,16 @@ vips_acosh( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_atanh( VipsImage *in, VipsImage **out, ... )
+vips_atanh(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_ATANH, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_ATANH, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -565,16 +594,16 @@ vips_atanh( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_log( VipsImage *in, VipsImage **out, ... )
+vips_log(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_LOG, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_LOG, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -588,16 +617,16 @@ vips_log( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_log10( VipsImage *in, VipsImage **out, ... )
+vips_log10(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_LOG10, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_LOG10, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -611,16 +640,16 @@ vips_log10( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_exp( VipsImage *in, VipsImage **out, ... )
+vips_exp(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_EXP, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_EXP, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -634,14 +663,14 @@ vips_exp( VipsImage *in, VipsImage **out, ... )
  * Returns: 0 on success, -1 on error
  */
 int
-vips_exp10( VipsImage *in, VipsImage **out, ... )
+vips_exp10(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_mathv( in, out, VIPS_OPERATION_MATH_EXP10, ap );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_mathv(in, out, VIPS_OPERATION_MATH_EXP10, ap);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
