@@ -19,28 +19,28 @@
 
 /*
 
-    This file is part of VIPS.
-    
-    VIPS is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+	This file is part of VIPS.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
+	VIPS is free software; you can redistribute it and/or modify
+	it under the terms of the GNU Lesser General Public License as published by
+	the Free Software Foundation; either version 2 of the License, or
+	(at your option) any later version.
 
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA
+	This program is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	GNU Lesser General Public License for more details.
+
+	You should have received a copy of the GNU Lesser General Public License
+	along with this program; if not, write to the Free Software
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+	02110-1301  USA
 
  */
 
 /*
 
-    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
+	These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
 
  */
 
@@ -58,44 +58,44 @@
 typedef VipsColourCode VipsLabS2LabQ;
 typedef VipsColourCodeClass VipsLabS2LabQClass;
 
-G_DEFINE_TYPE( VipsLabS2LabQ, vips_LabS2LabQ, VIPS_TYPE_COLOUR_CODE );
+G_DEFINE_TYPE(VipsLabS2LabQ, vips_LabS2LabQ, VIPS_TYPE_COLOUR_CODE);
 
 /* Convert n pels from signed short to IM_CODING_LABQ.
  */
 static void
-vips_LabS2LabQ_line( VipsColour *colour, VipsPel *out, VipsPel **in, int width )
+vips_LabS2LabQ_line(VipsColour *colour, VipsPel *out, VipsPel **in, int width)
 {
 	signed short *p = (signed short *) in[0];
 	unsigned char *q = (unsigned char *) out;
 
 	int i;
 
-	for( i = 0; i < width; i++ ) {
+	for (i = 0; i < width; i++) {
 		int l, a, b;
 		unsigned char ext;
 
-		/* Get LAB, rounding to 10, 11, 11. 
+		/* Get LAB, rounding to 10, 11, 11.
 		 */
 		l = p[0] + 16;
-		l = VIPS_CLIP( 0, l, 32767 );
+		l = VIPS_CLIP(0, l, 32767);
 		l >>= 5;
 
 		/* Make sure we round -ves in the right direction!
 		 */
 		a = p[1];
-		if( a >= 0 )
+		if (a >= 0)
 			a += 16;
 		else
 			a -= 16;
-		a = VIPS_CLIP( -32768, a, 32767 );
+		a = VIPS_CLIP(-32768, a, 32767);
 		a >>= 5;
 
 		b = p[2];
-		if( b >= 0 )
+		if (b >= 0)
 			b += 16;
 		else
 			b -= 16;
-		b = VIPS_CLIP( -32768, b, 32767 );
+		b = VIPS_CLIP(-32768, b, 32767);
 		b >>= 5;
 
 		p += 3;
@@ -118,22 +118,22 @@ vips_LabS2LabQ_line( VipsColour *colour, VipsPel *out, VipsPel **in, int width )
 }
 
 static void
-vips_LabS2LabQ_class_init( VipsLabS2LabQClass *class )
+vips_LabS2LabQ_class_init(VipsLabS2LabQClass *class)
 {
 	VipsObjectClass *object_class = (VipsObjectClass *) class;
-	VipsColourClass *colour_class = VIPS_COLOUR_CLASS( class );
+	VipsColourClass *colour_class = VIPS_COLOUR_CLASS(class);
 
 	object_class->nickname = "LabS2LabQ";
-	object_class->description = _( "transform short Lab to LabQ coding" );
+	object_class->description = _("transform short Lab to LabQ coding");
 
 	colour_class->process_line = vips_LabS2LabQ_line;
 }
 
 static void
-vips_LabS2LabQ_init( VipsLabS2LabQ *LabS2LabQ )
+vips_LabS2LabQ_init(VipsLabS2LabQ *LabS2LabQ)
 {
-	VipsColour *colour = VIPS_COLOUR( LabS2LabQ );
-	VipsColourCode *code = VIPS_COLOUR_CODE( LabS2LabQ );
+	VipsColour *colour = VIPS_COLOUR(LabS2LabQ);
+	VipsColourCode *code = VIPS_COLOUR_CODE(LabS2LabQ);
 
 	colour->coding = VIPS_CODING_LABQ;
 	colour->interpretation = VIPS_INTERPRETATION_LABQ;
@@ -158,14 +158,14 @@ vips_LabS2LabQ_init( VipsLabS2LabQ *LabS2LabQ )
  * Returns: 0 on success, -1 on error.
  */
 int
-vips_LabS2LabQ( VipsImage *in, VipsImage **out, ... )
+vips_LabS2LabQ(VipsImage *in, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_call_split( "LabS2LabQ", ap, in, out );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_call_split("LabS2LabQ", ap, in, out);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
