@@ -72,8 +72,14 @@ vips_XYZ2Yxy_line(VipsColour *colour, VipsPel *out, VipsPel **in, int width)
 
 		p += 3;
 
-		x = X / total;
-		y = Y / total;
+		if (total == 0.0) {
+			x = 0;
+			y = 0;
+		}
+		else {
+			x = X / total;
+			y = Y / total;
+		}
 
 		q[0] = Y;
 		q[1] = x;
