@@ -58,7 +58,6 @@
 #include <limits.h>
 
 #include <vips/vips.h>
-#include <vips/vips7compat.h>
 #include <vips/internal.h>
 #include <vips/debug.h>
 
@@ -323,7 +322,7 @@ static int
 getext_vec(im_object *argv)
 {
 	void **out = (void **) &argv[1];
-	int size;
+	size_t size;
 
 	/* void/char confusion is fine.
 	 */
@@ -749,7 +748,7 @@ im_load_plugins(const char *fmt, ...)
 	(void) im_vsnprintf(dir_name, VIPS_PATH_MAX - 1, fmt, ap);
 	va_end(ap);
 
-	g_info("im_load_plugins: searching \"%s\"\n", dir_name);
+	g_info("im_load_plugins: searching \"%s\"", dir_name);
 
 	if (!(dir = g_dir_open(dir_name, 0, NULL)))
 		/* Silent success for dir not there.
