@@ -549,8 +549,8 @@ vips_foreign_find_load_sub(VipsForeignLoadClass *load_class,
 
 	/* Ignore the buffer and source loaders.
 	 */
-	if (vips_ispostfix(object_class->nickname, "_buffer") ||
-		vips_ispostfix(object_class->nickname, "_source"))
+	if (g_str_has_suffix(object_class->nickname, "_buffer") ||
+		g_str_has_suffix(object_class->nickname, "_source"))
 		return NULL;
 
 #ifdef DEBUG
@@ -665,7 +665,7 @@ vips_foreign_find_load_buffer_sub(VipsForeignLoadClass *load_class,
 
 	/* Skip non-buffer loaders.
 	 */
-	if (!vips_ispostfix(object_class->nickname, "_buffer"))
+	if (!g_str_has_suffix(object_class->nickname, "_buffer"))
 		return NULL;
 
 	if (load_class->is_a_buffer) {
@@ -723,7 +723,7 @@ vips_foreign_find_load_source_sub(void *item, void *a, void *b)
 
 	/* Skip non-source loaders.
 	 */
-	if (!vips_ispostfix(object_class->nickname, "_source"))
+	if (!g_str_has_suffix(object_class->nickname, "_source"))
 		return NULL;
 
 	if (load_class->is_a_source) {
@@ -1029,7 +1029,7 @@ vips_foreign_load_start(VipsImage *out, void *a, void *b)
 		 * Some versions of ImageMagick give different results between
 		 * Ping and Load for some formats, for example.
 		 *
-		 * If the load fails, we need to stop
+		 * If the load fails, we need to stop.
 		 */
 		if (class->load(load) ||
 			vips_image_pio_input(load->real) ||
@@ -1433,8 +1433,7 @@ vips__foreign_convert_saveable(VipsImage *in, VipsImage **ready,
 			in->Type != VIPS_INTERPRETATION_XYZ) {
 			VipsImage *out;
 
-			if (vips_colourspace(in, &out,
-					VIPS_INTERPRETATION_scRGB, NULL)) {
+			if (vips_colourspace(in, &out, VIPS_INTERPRETATION_scRGB, NULL)) {
 				g_object_unref(in);
 				return -1;
 			}
@@ -1723,10 +1722,10 @@ vips_foreign_save_remove_metadata(VipsImage *image,
 	VipsForeignKeep keep = *((VipsForeignKeep *) user_data);
 
 	// we are only interested in metadata
-	if (!vips_isprefix(field, "png-comment-") &&
-		!vips_isprefix(field, "magickprofile-") &&
+	if (!vips_isprefix("png-comment-", field) &&
+		!vips_isprefix("magickprofile-", field) &&
 		strcmp(field, VIPS_META_IMAGEDESCRIPTION) != 0 &&
-		!vips_ispostfix(field, "-data"))
+		!g_str_has_suffix(field, "-data"))
 		return NULL;
 
 	if ((strcmp(field, VIPS_META_EXIF_NAME) == 0 &&
@@ -1801,8 +1800,7 @@ vips_foreign_save_build(VipsObject *object)
 		save->keep |= VIPS_FOREIGN_KEEP_ICC;
 
 	if (save->in) {
-		VipsForeignSaveClass *class =
-			VIPS_FOREIGN_SAVE_GET_CLASS(save);
+		VipsForeignSaveClass *class = VIPS_FOREIGN_SAVE_GET_CLASS(save);
 		VipsImage *ready;
 		VipsImage *x;
 
@@ -1963,8 +1961,8 @@ vips_foreign_find_save_sub(VipsForeignSaveClass *save_class,
 
 	/* Skip non-file savers.
 	 */
-	if (vips_ispostfix(object_class->nickname, "_buffer") ||
-		vips_ispostfix(object_class->nickname, "_target"))
+	if (g_str_has_suffix(object_class->nickname, "_buffer") ||
+		g_str_has_suffix(object_class->nickname, "_target"))
 		return NULL;
 
 	/* vips_foreign_find_save() has already removed any options from the
@@ -2125,7 +2123,7 @@ vips_foreign_find_save_target_sub(VipsForeignSaveClass *save_class,
 
 	if (!G_TYPE_IS_ABSTRACT(G_TYPE_FROM_CLASS(class)) &&
 		class->suffs &&
-		vips_ispostfix(object_class->nickname, "_target") &&
+		g_str_has_suffix(object_class->nickname, "_target") &&
 		vips_filename_suffix_match(suffix, class->suffs))
 		return save_class;
 
@@ -2183,7 +2181,7 @@ vips_foreign_find_save_buffer_sub(VipsForeignSaveClass *save_class,
 
 	if (!G_TYPE_IS_ABSTRACT(G_TYPE_FROM_CLASS(class)) &&
 		class->suffs &&
-		vips_ispostfix(object_class->nickname, "_buffer") &&
+		g_str_has_suffix(object_class->nickname, "_buffer") &&
 		vips_filename_suffix_match(suffix, class->suffs))
 		return save_class;
 
@@ -2721,7 +2719,7 @@ vips_jxlsave_target(VipsImage *in, VipsTarget *target, ...)
  * * @dpi: %gdouble, render at this DPI
  * * @scale: %gdouble, scale render by this factor
  * * @background: #VipsArrayDouble background colour
- * * @password: %gchararray background colour
+ * * @password: %gchararray PDF password
  *
  * Render a PDF file into a VIPS image.
  *
@@ -3009,8 +3007,9 @@ vips_foreign_operation_init(void)
 	extern GType vips_foreign_save_tiff_target_get_type(void);
 
 	extern GType vips_foreign_load_raw_get_type(void);
-	extern GType vips_foreign_save_raw_get_type(void);
-	extern GType vips_foreign_save_raw_fd_get_type(void);
+	extern GType vips_foreign_save_raw_file_get_type(void);
+	extern GType vips_foreign_save_raw_buffer_get_type(void);
+	extern GType vips_foreign_save_raw_target_get_type(void);
 
 	extern GType vips_foreign_load_magick_file_get_type(void);
 	extern GType vips_foreign_load_magick_buffer_get_type(void);
@@ -3090,8 +3089,9 @@ vips_foreign_operation_init(void)
 	vips_foreign_print_matrix_get_type();
 
 	vips_foreign_load_raw_get_type();
-	vips_foreign_save_raw_get_type();
-	vips_foreign_save_raw_fd_get_type();
+	vips_foreign_save_raw_file_get_type();
+	vips_foreign_save_raw_buffer_get_type();
+	vips_foreign_save_raw_target_get_type();
 
 	vips_foreign_load_vips_file_get_type();
 	vips_foreign_load_vips_source_get_type();
