@@ -1,6 +1,6 @@
 /* save with libMagick
  *
- * 22/12/17 dlemstra 
+ * 22/12/17 dlemstra
  * 6/2/19 DarthSim
  * 	- fix GraphicsMagick support
  * 17/2/19
@@ -9,7 +9,7 @@
  * 29/6/19
  * 	- support "strip" option
  * 6/7/19 [deftomat]
- * 	- support array of delays 
+ * 	- support array of delays
  * 5/8/19 DarthSim
  * 	- support GIF optimization
  * 21/4/21 kleisauke
@@ -18,28 +18,28 @@
 
 /*
 
-    This file is part of VIPS.
-    
-    VIPS is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+	This file is part of VIPS.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
+	VIPS is free software; you can redistribute it and/or modify
+	it under the terms of the GNU Lesser General Public License as published by
+	the Free Software Foundation; either version 2 of the License, or
+	(at your option) any later version.
 
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA
+	This program is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	GNU Lesser General Public License for more details.
+
+	You should have received a copy of the GNU Lesser General Public License
+	along with this program; if not, write to the Free Software
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+	02110-1301  USA
 
  */
 
 /*
 
-    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
+	These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
 
  */
 
@@ -56,8 +56,8 @@
 
 /**
  * vips_magicksave: (method)
- * @in: image to save 
- * @filename: file to write to 
+ * @in: image to save
+ * @filename: file to write to
  * @...: %NULL-terminated list of optional named arguments
  *
  * Optional arguments:
@@ -92,21 +92,21 @@
  * Returns: 0 on success, -1 on error.
  */
 int
-vips_magicksave( VipsImage *in, const char *filename, ... )
+vips_magicksave(VipsImage *in, const char *filename, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, filename );
-	result = vips_call_split( "magicksave", ap, in, filename );
-	va_end( ap );
+	va_start(ap, filename);
+	result = vips_call_split("magicksave", ap, in, filename);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
  * vips_magicksave_buffer: (method)
- * @in: image to save 
+ * @in: image to save
  * @buf: (array length=len) (element-type guint8): return output buffer here
  * @len: (type gsize): return output length here
  * @...: %NULL-terminated list of optional named arguments
@@ -119,7 +119,7 @@ vips_magicksave( VipsImage *in, const char *filename, ... )
  * * @optimize_gif_transparency: %gboolean, apply GIF transparency optimization
  * * @bitdepth: %gint, number of bits per pixel
  *
- * As vips_magicksave(), but save to a memory buffer. 
+ * As vips_magicksave(), but save to a memory buffer.
  *
  * The address of the buffer is returned in @obuf, the length of the buffer in
  * @olen. You are responsible for freeing the buffer with g_free() when you
@@ -130,29 +130,29 @@ vips_magicksave( VipsImage *in, const char *filename, ... )
  * Returns: 0 on success, -1 on error.
  */
 int
-vips_magicksave_buffer( VipsImage *in, void **buf, size_t *len, ... )
+vips_magicksave_buffer(VipsImage *in, void **buf, size_t *len, ...)
 {
 	va_list ap;
 	VipsArea *area;
 	int result;
 
-	area = NULL; 
+	area = NULL;
 
-	va_start( ap, len );
-	result = vips_call_split( "magicksave_buffer", ap, in, &area );
-	va_end( ap );
+	va_start(ap, len);
+	result = vips_call_split("magicksave_buffer", ap, in, &area);
+	va_end(ap);
 
-	if( !result &&
-		area ) { 
-		if( buf ) {
+	if (!result &&
+		area) {
+		if (buf) {
 			*buf = area->data;
 			area->free_fn = NULL;
 		}
-		if( len ) 
+		if (len)
 			*len = area->length;
 
-		vips_area_unref( area );
+		vips_area_unref(area);
 	}
 
-	return( result );
+	return result;
 }
