@@ -564,7 +564,6 @@ vips_foreign_load_pdf_generate(VipsRegion *out_region,
 
 	int top;
 	int i;
-	int y;
 
 	/*
 	printf("vips_foreign_load_pdf_generate: "
@@ -612,17 +611,18 @@ vips_foreign_load_pdf_generate(VipsRegion *out_region,
 				0, 0, rect.width, rect.height, ink);
 		}
 
+		// pdfium writes bgra by default, we need rgba
 		FPDF_RenderPageBitmap(bitmap, pdf->page,
 			pdf->pages[i].left - rect.left,
 			pdf->pages[i].top - rect.top,
 			pdf->pages[i].width, pdf->pages[i].height,
-			0, 0);
+			0, FPDF_ANNOT | FPDF_REVERSE_BYTE_ORDER);
 
 		FPDF_FFLDraw(pdf->form, bitmap, pdf->page,
 			pdf->pages[i].left - rect.left,
 			pdf->pages[i].top - rect.top,
 			pdf->pages[i].width, pdf->pages[i].height,
-			0, 0);
+			0, FPDF_ANNOT | FPDF_REVERSE_BYTE_ORDER);
 
 		FPDFBitmap_Destroy(bitmap);
 
@@ -632,13 +632,6 @@ vips_foreign_load_pdf_generate(VipsRegion *out_region,
 		i += 1;
 	}
 
-	/* PDFium writes BGRA, we must swap.
-	 */
-	for (y = 0; y < r->height; y++)
-		vips__bgra2rgba(
-			(guint32 *) VIPS_REGION_ADDR(out_region, r->left, r->top + y),
-			r->width);
-
 	return 0;
 }
 
@@ -739,7 +732,7 @@ vips_foreign_load_pdf_class_init(VipsForeignLoadPdfClass *class)
 		_("Factor to scale by"),
 		VIPS_ARGUMENT_OPTIONAL_INPUT,
 		G_STRUCT_OFFSET(VipsForeignLoadPdf, scale),
-		0.001, 100000.0, 1.0);
+		0.0, 100000.0, 1.0);
 
 	VIPS_ARG_BOXED(class, "background", 14,
 		_("Background"),
@@ -791,11 +784,6 @@ vips_foreign_load_pdf_file_header(VipsForeignLoad *load)
 		->header(load);
 }
 
-static const char *vips_foreign_pdf_suffs[] = {
-	".pdf",
-	NULL
-};
-
 static int
 vips_foreign_load_pdf_file_build(VipsObject *object)
 {
@@ -814,33 +802,6 @@ vips_foreign_load_pdf_file_build(VipsObject *object)
 		->build(object);
 }
 
-static gboolean
-vips_foreign_load_pdf_is_a_buffer(const void *buf, size_t len)
-{
-	const guchar *str = (const guchar *) buf;
-
-	if (len >= 4 &&
-		str[0] == '%' &&
-		str[1] == 'P' &&
-		str[2] == 'D' &&
-		str[3] == 'F')
-		return 1;
-
-	return 0;
-}
-
-static gboolean
-vips_foreign_load_pdf_is_a(const char *filename)
-{
-	unsigned char buf[4];
-
-	if (vips__get_bytes(filename, buf, 4) == 4 &&
-		vips_foreign_load_pdf_is_a_buffer(buf, 4))
-		return 1;
-
-	return 0;
-}
-
 static void
 vips_foreign_load_pdf_file_class_init(
 	VipsForeignLoadPdfFileClass *class)
@@ -857,9 +818,9 @@ vips_foreign_load_pdf_file_class_init(
 	object_class->description = _("load PDF from file");
 	object_class->build = vips_foreign_load_pdf_file_build;
 
-	foreign_class->suffs = vips_foreign_pdf_suffs;
+	foreign_class->suffs = vips__pdf_suffs;
 
-	load_class->is_a = vips_foreign_load_pdf_is_a;
+	load_class->is_a = vips__pdf_is_a_file;
 	load_class->header = vips_foreign_load_pdf_file_header;
 
 	VIPS_ARG_STRING(class, "filename", 1,
@@ -920,7 +881,7 @@ vips_foreign_load_pdf_buffer_class_init(
 	object_class->description = _("load PDF from buffer");
 	object_class->build = vips_foreign_load_pdf_buffer_build;
 
-	load_class->is_a_buffer = vips_foreign_load_pdf_is_a_buffer;
+	load_class->is_a_buffer = vips__pdf_is_a_buffer;
 
 	VIPS_ARG_BOXED(class, "buffer", 1,
 		_("Buffer"),
@@ -962,18 +923,6 @@ vips_foreign_load_pdf_source_build(VipsObject *object)
 		->build(object);
 }
 
-static gboolean
-vips_foreign_load_pdf_source_is_a_source(VipsSource *source)
-{
-	const unsigned char *p;
-
-	return (p = vips_source_sniff(source, 4)) &&
-		p[0] == '%' &&
-		p[1] == 'P' &&
-		p[2] == 'D' &&
-		p[3] == 'F';
-}
-
 static void
 vips_foreign_load_pdf_source_class_init(
 	VipsForeignLoadPdfSourceClass *class)
@@ -992,7 +941,7 @@ vips_foreign_load_pdf_source_class_init(
 
 	operation_class->flags |= VIPS_OPERATION_NOCACHE;
 
-	load_class->is_a_source = vips_foreign_load_pdf_source_is_a_source;
+	load_class->is_a_source = vips__pdf_is_a_source;
 
 	VIPS_ARG_OBJECT(class, "source", 1,
 		_("Source"),
