@@ -324,7 +324,7 @@ vips_foreign_save_ppm_build(VipsObject *object)
 
 	/* Handle the deprecated squash parameter.
 	 */
-	if (vips_object_argument_isset(object, "squash"))
+	if (ppm->squash)
 		ppm->bitdepth = 1;
 
 	if (vips_check_uintorf("vips2ppm", image) ||
@@ -411,9 +411,6 @@ vips_foreign_save_ppm_build(VipsObject *object)
 				!vips_image_get_double(image, "pfm-scale", &scale))
 				;
 
-			if (vips_amiMSBfirst())
-				scale *= -1;
-
 			/* Need to be locale independent.
 			 */
 			g_ascii_dtostr(buf, G_ASCII_DTOSTR_BUF_SIZE, scale);
