@@ -359,6 +359,11 @@ typedef struct _RtiffHeader {
 	 */
 	gboolean we_decompress;
 
+	/* TRUE if we use TIFFRGBAImage or TIFFReadRGBATile.
+	 * Used for COMPRESSION_OJPEG
+	 */
+	gboolean read_as_rgba;
+
 } RtiffHeader;
 
 /* Scanline-type process function.
@@ -690,6 +695,45 @@ rtiff_strip_read(Rtiff *rtiff, int strip, tdata_t buf)
 	return 0;
 }
 
+static int
+rtiff_rgba_strip_read(Rtiff *rtiff, int strip, tdata_t buf)
+{
+	RtiffHeader *header = &rtiff->header;
+
+	TIFFRGBAImage img;
+	guint32 rows_to_read;
+	char err[1024] = "";
+
+#ifdef DEBUG_VERBOSE
+	printf("rtiff_rgba_strip_read: reading strip %d\n", strip);
+#endif /*DEBUG_VERBOSE*/
+
+	if (!TIFFRGBAImageOK(rtiff->tiff, err) ||
+		!TIFFRGBAImageBegin(&img, rtiff->tiff, 0, err)) {
+		vips_foreign_load_invalidate(rtiff->out);
+		vips_error("tiff2vips", "%s", err);
+		return -1;
+	}
+
+	img.req_orientation = header->orientation;
+	img.row_offset = strip * header->rows_per_strip;
+	img.col_offset = 0;
+
+	rows_to_read =
+		VIPS_MIN(header->rows_per_strip, header->height - img.row_offset);
+
+	if (!TIFFRGBAImageGet(&img, buf, header->width, rows_to_read)) {
+		TIFFRGBAImageEnd(&img);
+		vips_foreign_load_invalidate(rtiff->out);
+		vips_error("tiff2vips", "%s", _("read error"));
+		return -1;
+	}
+
+	TIFFRGBAImageEnd(&img);
+
+	return 0;
+}
+
 /* We need to hint to libtiff what format we'd like pixels in.
  */
 static void
@@ -697,16 +741,15 @@ rtiff_set_decode_format(Rtiff *rtiff)
 {
 	/* Ask for YCbCr->RGB for jpg data.
 	 */
-	if (rtiff->header.compression == COMPRESSION_JPEG)
-		TIFFSetField(rtiff->tiff,
-			TIFFTAG_JPEGCOLORMODE, JPEGCOLORMODE_RGB);
+	if (rtiff->header.compression == COMPRESSION_JPEG ||
+		rtiff->header.compression == COMPRESSION_OJPEG)
+		TIFFSetField(rtiff->tiff, TIFFTAG_JPEGCOLORMODE, JPEGCOLORMODE_RGB);
 
 	/* Ask for SGI LOGLUV as 3xfloat.
 	 */
 	if (rtiff->header.photometric_interpretation ==
 		PHOTOMETRIC_LOGLUV)
-		TIFFSetField(rtiff->tiff,
-			TIFFTAG_SGILOGDATAFMT, SGILOGDATAFMT_FLOAT);
+		TIFFSetField(rtiff->tiff, TIFFTAG_SGILOGDATAFMT, SGILOGDATAFMT_FLOAT);
 }
 
 static int
@@ -719,8 +762,7 @@ rtiff_set_page(Rtiff *rtiff, int page)
 #endif /*DEBUG*/
 
 		if (!TIFFSetDirectory(rtiff->tiff, page)) {
-			vips_error("tiff2vips",
-				_("TIFF does not contain page %d"), page);
+			vips_error("tiff2vips", _("TIFF does not contain page %d"), page);
 			return -1;
 		}
 
@@ -730,8 +772,7 @@ rtiff_set_page(Rtiff *rtiff, int page)
 
 			if (!TIFFGetField(rtiff->tiff, TIFFTAG_SUBIFD,
 					&subifd_count, &subifd_offsets)) {
-				vips_error("tiff2vips",
-					"%s", _("no SUBIFD tag"));
+				vips_error("tiff2vips", "%s", _("no SUBIFD tag"));
 				return -1;
 			}
 
@@ -745,8 +786,7 @@ rtiff_set_page(Rtiff *rtiff, int page)
 
 			if (!TIFFSetSubDirectory(rtiff->tiff,
 					subifd_offsets[rtiff->subifd])) {
-				vips_error("tiff2vips",
-					"%s", _("subdirectory unreadable"));
+				vips_error("tiff2vips", "%s", _("subdirectory unreadable"));
 				return -1;
 			}
 		}
@@ -787,8 +827,7 @@ static int
 rtiff_check_samples(Rtiff *rtiff, int samples_per_pixel)
 {
 	if (rtiff->header.samples_per_pixel != samples_per_pixel) {
-		vips_error("tiff2vips",
-			_("not %d bands"), samples_per_pixel);
+		vips_error("tiff2vips", _("not %d bands"), samples_per_pixel);
 		return -1;
 	}
 
@@ -801,8 +840,7 @@ static int
 rtiff_check_min_samples(Rtiff *rtiff, int samples_per_pixel)
 {
 	if (rtiff->header.samples_per_pixel < samples_per_pixel) {
-		vips_error("tiff2vips",
-			_("not at least %d samples per pixel"),
+		vips_error("tiff2vips", _("not at least %d samples per pixel"),
 			samples_per_pixel);
 		return -1;
 	}
@@ -830,8 +868,7 @@ rtiff_check_interpretation(Rtiff *rtiff, int photometric_interpretation)
 {
 	if (rtiff->header.photometric_interpretation !=
 		photometric_interpretation) {
-		vips_error("tiff2vips",
-			_("not photometric interpretation %d"),
+		vips_error("tiff2vips", _("not photometric interpretation %d"),
 			photometric_interpretation);
 		return -1;
 	}
@@ -843,8 +880,7 @@ static int
 rtiff_check_bits(Rtiff *rtiff, int bits_per_sample)
 {
 	if (rtiff->header.bits_per_sample != bits_per_sample) {
-		vips_error("tiff2vips",
-			_("not %d bits per sample"), bits_per_sample);
+		vips_error("tiff2vips", _("not %d bits per sample"), bits_per_sample);
 		return -1;
 	}
 
@@ -1623,7 +1659,7 @@ static void
 rtiff_memcpy_f16_line(Rtiff *rtiff, VipsPel *q, VipsPel *p, int n, void *client)
 {
 	VipsImage *im = (VipsImage *) client;
-	size_t len = n * im->Bands;
+	size_t len = (size_t) n * im->Bands;
 
 	if (im->BandFmt == VIPS_FORMAT_COMPLEX ||
 		im->BandFmt == VIPS_FORMAT_DPCOMPLEX)
@@ -1662,7 +1698,7 @@ rtiff_parse_copy(Rtiff *rtiff, VipsImage *out)
 
 	if (samples_per_pixel >= 3 &&
 		(photometric_interpretation == PHOTOMETRIC_RGB ||
-			photometric_interpretation == PHOTOMETRIC_YCBCR)) {
+		photometric_interpretation == PHOTOMETRIC_YCBCR)) {
 		if (out->BandFmt == VIPS_FORMAT_USHORT)
 			out->Type = VIPS_INTERPRETATION_RGB16;
 		else if (!vips_band_format_isint(out->BandFmt))
@@ -1697,6 +1733,27 @@ rtiff_parse_copy(Rtiff *rtiff, VipsImage *out)
 		 */
 		rtiff->memcpy = photometric_interpretation != PHOTOMETRIC_YCBCR;
 	}
+
+	return 0;
+}
+
+/* Read an image as RGBA using TIFFRGBAImage
+ */
+static int
+rtiff_parse_rgba(Rtiff *rtiff, VipsImage *out)
+{
+	out->Bands = 4;
+	out->Type = VIPS_INTERPRETATION_sRGB;
+	out->BandFmt = VIPS_FORMAT_UCHAR;
+	out->Coding = VIPS_CODING_NONE;
+
+	rtiff->client = out;
+
+	/* We'll have RGBA areas of exact size as we need, so we can just copy it
+	 */
+	rtiff->sfn = rtiff_memcpy_line;
+	rtiff->memcpy = TRUE;
+
 	return 0;
 }
 
@@ -1712,6 +1769,10 @@ rtiff_pick_reader(Rtiff *rtiff)
 	int photometric_interpretation =
 		rtiff->header.photometric_interpretation;
 	int samples_per_pixel = rtiff->header.samples_per_pixel;
+	int read_as_rgba = rtiff->header.read_as_rgba;
+
+	if (read_as_rgba)
+		return rtiff_parse_rgba;
 
 	if (photometric_interpretation == PHOTOMETRIC_CIELAB) {
 		if (bits_per_sample == 8) {
@@ -1912,7 +1973,7 @@ rtiff_decompress_jpeg_fill_input_buffer(j_decompress_ptr cinfo)
 	 * buffer, so any request for more data beyond the given buffer size
 	 * is treated as an error.
 	 */
-	WARNMS(cinfo, JWRN_JPEG_EOF);
+	WARNMS(cinfo, JWRN_VIPS_IMAGE_EOF);
 
 	/* Insert a fake EOI marker
 	 */
@@ -2027,6 +2088,8 @@ rtiff_decompress_jpeg_run(Rtiff *rtiff, j_decompress_ptr cinfo,
 		break;
 
 	case PHOTOMETRIC_RGB:
+	case PHOTOMETRIC_CIELAB:
+		// RGB-compressed CIELAB is a possibility, amazingly
 		cinfo->jpeg_color_space = JCS_RGB;
 		bytes_per_pixel = 3;
 		break;
@@ -2044,7 +2107,7 @@ rtiff_decompress_jpeg_run(Rtiff *rtiff, j_decompress_ptr cinfo,
 	}
 
 	jpeg_calc_output_dimensions(cinfo);
-	bytes_per_scanline = cinfo->output_width * bytes_per_pixel;
+	bytes_per_scanline = (size_t) cinfo->output_width * bytes_per_pixel;
 
 	/* Double-check tile dimensions.
 	 */
@@ -2100,6 +2163,9 @@ rtiff_decompress_jpeg(Rtiff *rtiff, void *data, size_t data_len, void *out)
 
 	if (setjmp(eman.jmp) == 0) {
 		cinfo.err = jpeg_std_error(&eman.pub);
+		cinfo.err->addon_message_table = vips__jpeg_message_table;
+		cinfo.err->first_addon_message = 1000;
+		cinfo.err->last_addon_message = 1001;
 		eman.pub.error_exit = vips__new_error_exit;
 		eman.pub.emit_message = rtiff_decompress_jpeg_emit_message;
 		eman.pub.output_message = vips__new_output_message;
@@ -2162,6 +2228,35 @@ rtiff_decompress_tile(Rtiff *rtiff, tdata_t *in, tsize_t size, tdata_t *out)
 	return 0;
 }
 
+/* Decompress a tile to RGBA
+ */
+static int
+rtiff_read_rgba_tile(Rtiff *rtiff, int x, int y, tdata_t *buf)
+{
+	guint32 *u32_buf = (guint32 *) buf;
+
+	if (!TIFFReadRGBATile(rtiff->tiff, x, y, u32_buf))
+		return -1;
+
+	/* For some reason TIFFReadRGBATile decodes tiles upside down,
+	 * so we need to flip them.
+	 */
+	guint32 tile_width = rtiff->header.tile_width;
+	guint32 tile_height = rtiff->header.tile_height;
+
+	guint32 *up = u32_buf;
+	guint32 *down = u32_buf + (tile_height - 1) * tile_width;
+	for (int yy = 0; yy < tile_height / 2; yy++) {
+		for (int xx = 0; xx < tile_width; xx++)
+			VIPS_SWAP(guint32, up[xx], down[xx]);
+
+		up += tile_width;
+		down -= tile_width;
+	}
+
+	return 0;
+}
+
 /* Select a page and decompress a tile. This has to be a single operation,
  * since it changes the current page number in TIFF.
  */
@@ -2204,10 +2299,8 @@ rtiff_read_tile(RtiffSeq *seq, tdata_t *buf, int page, int x, int y)
 
 		/* Decompress outside the lock, so we get parallelism.
 		 */
-		if (rtiff_decompress_tile(rtiff,
-				seq->compressed_buf, size, buf)) {
-			vips_error("tiff2vips",
-				_("decompress error tile %d x %d"), x, y);
+		if (rtiff_decompress_tile(rtiff, seq->compressed_buf, size, buf)) {
+			vips_error("tiff2vips", _("decompress error tile %d x %d"), x, y);
 			return -1;
 		}
 	}
@@ -2219,7 +2312,12 @@ rtiff_read_tile(RtiffSeq *seq, tdata_t *buf, int page, int x, int y)
 			return -1;
 		}
 
-		if (TIFFReadTile(rtiff->tiff, buf, x, y, 0, 0) < 0) {
+		int result;
+		if (rtiff->header.read_as_rgba)
+			result = rtiff_read_rgba_tile(rtiff, x, y, buf);
+		else
+			result = TIFFReadTile(rtiff->tiff, buf, x, y, 0, 0) < 0;
+		if (result) {
 			vips_foreign_load_invalidate(rtiff->out);
 			g_rec_mutex_unlock(&rtiff->lock);
 			return -1;
@@ -2469,8 +2567,7 @@ rtiff_read_tilewise(Rtiff *rtiff, VipsImage *out)
 {
 	int tile_width = rtiff->header.tile_width;
 	int tile_height = rtiff->header.tile_height;
-	VipsImage **t = (VipsImage **)
-		vips_object_local_array(VIPS_OBJECT(out), 4);
+	VipsImage **t = (VipsImage **) vips_object_local_array(VIPS_OBJECT(out), 4);
 
 	VipsImage *in;
 
@@ -2481,8 +2578,7 @@ rtiff_read_tilewise(Rtiff *rtiff, VipsImage *out)
 	/* I don't have a sample images for tiled + separate, ban it for now.
 	 */
 	if (rtiff->header.separate) {
-		vips_error("tiff2vips",
-			"%s", _("tiled separate planes not supported"));
+		vips_error("tiff2vips", "%s", _("tiled separate planes not supported"));
 		return -1;
 	}
 
@@ -2501,8 +2597,7 @@ rtiff_read_tilewise(Rtiff *rtiff, VipsImage *out)
 			tile_width * tile_height;
 
 		if (rtiff->header.tile_size != vips_tile_size) {
-			vips_error("tiff2vips",
-				"%s", _("unsupported tiff image type"));
+			vips_error("tiff2vips", "%s", _("unsupported tiff image type"));
 			return -1;
 		}
 	}
@@ -2552,12 +2647,17 @@ rtiff_strip_read_interleaved(Rtiff *rtiff,
 	int samples_per_pixel = rtiff->header.samples_per_pixel;
 	int read_height = rtiff->header.read_height;
 	int bits_per_sample = rtiff->header.bits_per_sample;
+	int read_as_rgba = rtiff->header.read_as_rgba;
 	int strip_y = strip * read_height;
 
 	if (rtiff_set_page(rtiff, page))
 		return -1;
 
-	if (rtiff->header.separate) {
+	if (read_as_rgba) {
+		if (rtiff_rgba_strip_read(rtiff, strip, buf))
+			return -1;
+	}
+	else if (rtiff->header.separate) {
 		int page_width = rtiff->header.width;
 		int page_height = rtiff->header.height;
 		int strips_per_plane = 1 + (page_height - 1) / read_height;
@@ -2780,8 +2880,7 @@ rtiff_read_stripwise(Rtiff *rtiff, VipsImage *out)
 			vips_line_size /= 2;
 
 		if (vips_line_size != rtiff->header.scanline_size) {
-			vips_error("tiff2vips",
-				"%s", _("unsupported tiff image type"));
+			vips_error("tiff2vips", "%s", _("unsupported tiff image type"));
 			return -1;
 		}
 	}
@@ -2868,6 +2967,7 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 	toff_t *subifd_offsets;
 	char *image_description;
 	guint32 max_tile_dimension;
+	gboolean can_read_as_rgba;
 
 	if (!tfget32(rtiff->tiff, TIFFTAG_IMAGEWIDTH,
 			&header->width) ||
@@ -2883,9 +2983,34 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 			&header->inkset))
 		return -1;
 
+	header->read_as_rgba = FALSE;
+
+	/* TIFF images which can be read by TIFFRGBAImage or TIFFReadRGBATile.
+	 */
+	can_read_as_rgba =
+		(header->samples_per_pixel == 1 ||
+			header->samples_per_pixel == 3 ||
+			header->samples_per_pixel == 4) &&
+		(header->bits_per_sample == 1 ||
+			header->bits_per_sample == 2 ||
+			header->bits_per_sample == 4 ||
+			header->bits_per_sample == 8 ||
+			header->bits_per_sample == 16);
+
 	TIFFGetFieldDefaulted(rtiff->tiff,
 		TIFFTAG_COMPRESSION, &header->compression);
 
+	/* We'll decode old-style JPEG using the libtiff RGBA path.
+	 */
+	if (header->compression == COMPRESSION_OJPEG) {
+		if (!can_read_as_rgba) {
+			vips_error("tiff2vips", "%s", _("unsupported tiff image type"));
+			return -1;
+		}
+
+		header->read_as_rgba = TRUE;
+	}
+
 	/* One of the types we decompress?
 	 */
 	for (i = 0; i < VIPS_NUMBER(rtiff_we_decompress); i++)
@@ -2902,27 +3027,24 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 	 */
 	rtiff_set_decode_format(rtiff);
 
-	/* Request YCbCr expansion. libtiff complains if you do this for
-	 * non-jpg images. We must set this here since it changes the result
-	 * of scanline_size.
+	/* If there's YCbCr chroma subsampling and we're not already using one of
+	 * the JPEG decompressors, use the libtiff RGBA path.
 	 */
-	if (header->compression != COMPRESSION_JPEG &&
+	if (!header->read_as_rgba &&
+		header->compression != COMPRESSION_JPEG &&
 		header->photometric_interpretation == PHOTOMETRIC_YCBCR) {
-		/* We rely on the jpg decompressor to upsample chroma
-		 * subsampled images. If there is chroma subsampling but
-		 * no jpg compression, we have to give up.
-		 *
-		 * tiffcp fails for images like this too.
-		 */
 		guint16 hsub, vsub;
 
 		TIFFGetFieldDefaulted(rtiff->tiff,
 			TIFFTAG_YCBCRSUBSAMPLING, &hsub, &vsub);
-		if (hsub != 1 ||
-			vsub != 1) {
-			vips_error("tiff2vips",
-				"%s", _("subsampled images not supported"));
-			return -1;
+		if (hsub != 1 || vsub != 1) {
+			if (!can_read_as_rgba) {
+				vips_error("tiff2vips",
+					"%s", _("subsampled images not supported"));
+				return -1;
+			}
+
+			header->read_as_rgba = TRUE;
 		}
 	}
 
@@ -2983,17 +3105,26 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 	 * that data is null-terminated and contains no embedded null
 	 * characters.
 	 */
-	if (TIFFGetField(rtiff->tiff,
-			TIFFTAG_IMAGEDESCRIPTION, &image_description))
+	if (TIFFGetField(rtiff->tiff, TIFFTAG_IMAGEDESCRIPTION, &image_description))
 		header->image_description =
-			vips_strdup(VIPS_OBJECT(rtiff->out),
-				image_description);
+			vips_strdup(VIPS_OBJECT(rtiff->out), image_description);
 
 	/* Tiles and strip images have slightly different fields.
 	 */
 	header->tiled = TIFFIsTiled(rtiff->tiff);
 
+	if (header->read_as_rgba) {
+		header->we_decompress = FALSE;
+		header->photometric_interpretation = PHOTOMETRIC_RGB;
+		header->samples_per_pixel = 4;
+		header->bits_per_sample = 8;
+		header->sample_format = SAMPLEFORMAT_UINT;
+		header->separate = FALSE;
+	}
+
 #ifdef DEBUG
+	printf("rtiff_header_read: header.read_as_rgba = %d\n",
+		header->read_as_rgba);
 	printf("rtiff_header_read: header.width = %d\n",
 		header->width);
 	printf("rtiff_header_read: header.height = %d\n",
@@ -3011,10 +3142,8 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 #endif /*DEBUG*/
 
 	if (header->tiled) {
-		if (!tfget32(rtiff->tiff,
-				TIFFTAG_TILEWIDTH, &header->tile_width) ||
-			!tfget32(rtiff->tiff,
-				TIFFTAG_TILELENGTH, &header->tile_height))
+		if (!tfget32(rtiff->tiff, TIFFTAG_TILEWIDTH, &header->tile_width) ||
+			!tfget32(rtiff->tiff, TIFFTAG_TILELENGTH, &header->tile_height))
 			return -1;
 
 #ifdef DEBUG
@@ -3039,8 +3168,14 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 			return -1;
 		}
 
-		header->tile_size = TIFFTileSize(rtiff->tiff);
-		header->tile_row_size = TIFFTileRowSize(rtiff->tiff);
+		if (header->read_as_rgba) {
+			header->tile_row_size = header->tile_width * 4;
+			header->tile_size = header->tile_row_size * header->tile_height;
+		}
+		else {
+			header->tile_size = TIFFTileSize(rtiff->tiff);
+			header->tile_row_size = TIFFTileRowSize(rtiff->tiff);
+		}
 
 #ifdef DEBUG
 		printf("rtiff_header_read: header.tile_size = %zd\n",
@@ -3073,10 +3208,27 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 		if (!tfget32(rtiff->tiff,
 				TIFFTAG_ROWSPERSTRIP, &header->rows_per_strip))
 			return -1;
-		header->strip_size = TIFFStripSize(rtiff->tiff);
-		header->scanline_size = TIFFScanlineSize(rtiff->tiff);
+
+		/* rows_per_strip can be 2 ** 32 - 1, meaning the
+		 * whole image. Clip this down to height to avoid
+		 * confusing vips.
+		 *
+		 * And it mustn't be zero.
+		 */
+		header->rows_per_strip = VIPS_CLIP(1,
+			header->rows_per_strip, header->height);
+
 		header->number_of_strips = TIFFNumberOfStrips(rtiff->tiff);
 
+		if (header->read_as_rgba) {
+			header->scanline_size = header->width * 4;
+			header->strip_size = header->scanline_size * header->rows_per_strip;
+		}
+		else {
+			header->scanline_size = TIFFScanlineSize(rtiff->tiff);
+			header->strip_size = TIFFStripSize(rtiff->tiff);
+		}
+
 #ifdef DEBUG
 		printf("rtiff_header_read: header.rows_per_strip = %d\n",
 			header->rows_per_strip);
@@ -3103,26 +3255,20 @@ rtiff_header_read(Rtiff *rtiff, RtiffHeader *header)
 		 * Don't try scanline reading for YCbCr images.
 		 * TIFFScanlineSize() will not work in this case due to
 		 * chroma subsampling.
+		 *
+		 * Don't use scanline reading if we're going to use TIFFRGBAImage
 		 */
 		if (header->rows_per_strip > 128 &&
 			!header->separate &&
-			header->photometric_interpretation !=
-				PHOTOMETRIC_YCBCR) {
+			header->photometric_interpretation != PHOTOMETRIC_YCBCR &&
+			!header->read_as_rgba) {
 			header->read_scanlinewise = TRUE;
 			header->read_height = 1;
 			header->read_size = rtiff->header.scanline_size;
 		}
 		else {
 			header->read_scanlinewise = FALSE;
-
-			/* rows_per_strip can be 2 ** 32 - 1, meaning the
-			 * whole image. Clip this down to height to avoid
-			 * confusing vips.
-			 *
-			 * And it mustn't be zero.
-			 */
-			header->read_height = VIPS_CLIP(1,
-				header->rows_per_strip, header->height);
+			header->read_height = header->rows_per_strip;
 			header->read_size = header->strip_size;
 		}
 
@@ -3174,8 +3320,7 @@ rtiff_header_equal(RtiffHeader *h1, RtiffHeader *h2)
 		h1->height != h2->height ||
 		h1->samples_per_pixel != h2->samples_per_pixel ||
 		h1->bits_per_sample != h2->bits_per_sample ||
-		h1->photometric_interpretation !=
-			h2->photometric_interpretation ||
+		h1->photometric_interpretation != h2->photometric_interpretation ||
 		h1->sample_format != h2->sample_format ||
 		h1->compression != h2->compression ||
 		h1->separate != h2->separate ||
@@ -3239,8 +3384,7 @@ rtiff_header_read_all(Rtiff *rtiff)
 				return -1;
 
 			if (!rtiff_header_equal(&rtiff->header, &header)) {
-				vips_error("tiff2vips",
-					_("page %d differs from page %d"),
+				vips_error("tiff2vips", _("page %d differs from page %d"),
 					rtiff->page + i, rtiff->page);
 				return -1;
 			}
