@@ -159,6 +159,12 @@
 #define MAX_BYTES_IN_MARKER 65533  /* maximum data len of a JPEG marker */
 #define MAX_DATA_BYTES_IN_MARKER (MAX_BYTES_IN_MARKER - ICC_OVERHEAD_LEN)
 
+const char *vips__jpeg_message_table[] = {
+	"premature end of JPEG image",
+	"unable to write to target",
+	NULL
+};
+
 /* New output message method - send to VIPS.
  */
 void
@@ -229,6 +235,9 @@ write_new(void)
 
 	write->row_pointer = NULL;
 	write->cinfo.err = jpeg_std_error(&write->eman.pub);
+	write->cinfo.err->addon_message_table = vips__jpeg_message_table;
+	write->cinfo.err->first_addon_message = 1000;
+	write->cinfo.err->last_addon_message = 1001;
 	write->cinfo.dest = NULL;
 	write->eman.pub.error_exit = vips__new_error_exit;
 	write->eman.pub.output_message = vips__new_output_message;
@@ -667,16 +676,21 @@ set_cinfo(struct jpeg_compress_struct *cinfo,
 	if (progressive)
 		jpeg_simple_progression(cinfo);
 
-	if (subsample_mode == VIPS_FOREIGN_SUBSAMPLE_OFF ||
-		(subsample_mode == VIPS_FOREIGN_SUBSAMPLE_AUTO &&
-			qfac >= 90)) {
-		int i;
+	/* We must set chroma subsampling explicitly since some libjpegs do not
+	 * enable this by default.
+	 */
+	if (in->Bands == 3 &&
+		(subsample_mode == VIPS_FOREIGN_SUBSAMPLE_ON ||
+			(subsample_mode == VIPS_FOREIGN_SUBSAMPLE_AUTO &&
+				qfac < 90)))
+		cinfo->comp_info[0].h_samp_factor = cinfo->comp_info[0].v_samp_factor = 2;
+	else
+		cinfo->comp_info[0].h_samp_factor = cinfo->comp_info[0].v_samp_factor = 1;
 
-		for (i = 0; i < in->Bands; i++) {
-			cinfo->comp_info[i].h_samp_factor = 1;
-			cinfo->comp_info[i].v_samp_factor = 1;
-		}
-	}
+	/* Rest should have sampling factors 1,1.
+	 */
+	for (int i = 1; i < in->Bands; i++)
+		cinfo->comp_info[i].h_samp_factor = cinfo->comp_info[i].v_samp_factor = 1;
 
 	/* Only write the JFIF headers if we have no EXIF.
 	 * Some readers get confused if you set both.
@@ -806,7 +820,7 @@ empty_output_buffer(j_compress_ptr cinfo)
 
 	if (vips_target_write(dest->target,
 			dest->buf, TARGET_BUFFER_SIZE))
-		ERREXIT(cinfo, JERR_FILE_WRITE);
+		ERREXIT(cinfo, JERR_VIPS_TARGET_WRITE);
 
 	dest->pub.next_output_byte = dest->buf;
 	dest->pub.free_in_buffer = TARGET_BUFFER_SIZE;
@@ -834,7 +848,7 @@ term_destination(j_compress_ptr cinfo)
 
 	if (vips_target_write(dest->target,
 			dest->buf, TARGET_BUFFER_SIZE - dest->pub.free_in_buffer))
-		ERREXIT(cinfo, JERR_FILE_WRITE);
+		ERREXIT(cinfo, JERR_VIPS_TARGET_WRITE);
 }
 
 /* Set dest to one of our objects.
