@@ -86,12 +86,6 @@
 #include <vips/internal.h>
 #include <vips/debug.h>
 
-/* For the vips__image_sizeof_bandformat declaration.
- */
-#if ENABLE_DEPRECATED
-#include <vips/vips7compat.h>
-#endif
-
 /**
  * SECTION: header
  * @short_description: get, set and walk image headers
@@ -613,6 +607,8 @@ vips_image_default_interpretation(const VipsImage *image)
 	case VIPS_FORMAT_SHORT:
 	case VIPS_FORMAT_UINT:
 	case VIPS_FORMAT_INT:
+	case VIPS_FORMAT_FLOAT:
+	case VIPS_FORMAT_DOUBLE:
 		switch (image->Bands) {
 		case 1:
 		case 2:
@@ -620,6 +616,12 @@ vips_image_default_interpretation(const VipsImage *image)
 
 		case 3:
 		case 4:
+			// we don't send float/double to scrgb, that's very likely to
+			// cause much more confusion, since "linear" makes float rgg all
+			// the time
+			//
+			// we do send u16 to rgb16/grey16 since that's a common case,
+			// see below
 			return VIPS_INTERPRETATION_sRGB;
 
 		default:
@@ -649,21 +651,6 @@ vips_image_default_interpretation(const VipsImage *image)
 			return VIPS_INTERPRETATION_MULTIBAND;
 		}
 
-	case VIPS_FORMAT_FLOAT:
-	case VIPS_FORMAT_DOUBLE:
-		switch (image->Bands) {
-		case 1:
-		case 2:
-			return VIPS_INTERPRETATION_B_W;
-
-		case 3:
-		case 4:
-			return VIPS_INTERPRETATION_scRGB;
-
-		default:
-			return VIPS_INTERPRETATION_MULTIBAND;
-		}
-
 	case VIPS_FORMAT_COMPLEX:
 	case VIPS_FORMAT_DPCOMPLEX:
 		return VIPS_INTERPRETATION_FOURIER;
@@ -1295,7 +1282,10 @@ vips_set_value_from_pointer(GValue *value, void *data)
 	else if (fundamental == G_TYPE_ENUM)
 		g_value_set_enum(value, *((int *) data));
 	else if (fundamental == G_TYPE_STRING)
-		g_value_set_string(value, *((char **) data));
+		// we don't want to copy the string (ie. the filename, usually) since
+		// it'll then be freed when the value is unset ... instead we must
+		// directly use the pointer owned by the VipsImage
+		g_value_set_static_string(value, *((char **) data));
 	else
 		g_warning("%s: unimplemented vips_set_value_from_pointer() type %s",
 			G_STRLOC,
@@ -1360,6 +1350,7 @@ vips_image_get(const VipsImage *image, const char *name, GValue *value_copy)
 			g_value_init(value_copy, gtype);
 			vips_set_value_from_pointer(value_copy,
 				G_STRUCT_MEMBER_P(image, field->offset));
+
 			return 0;
 		}
 	}
@@ -1373,6 +1364,7 @@ vips_image_get(const VipsImage *image, const char *name, GValue *value_copy)
 			g_value_init(value_copy, gtype);
 			vips_set_value_from_pointer(value_copy,
 				G_STRUCT_MEMBER_P(image, field->offset));
+
 			return 0;
 		}
 	}
