@@ -246,55 +246,6 @@ vips_hash_table_map(GHashTable *hash, VipsSListMap2Fn fn, void *a, void *b)
 	return pair.result;
 }
 
-/* Like strncpy(), but always NULL-terminate, and don't pad with NULLs.
- * If @n is 100 and @src is more than 99 characters, 99 are copied and the
- * final byte of @dest is set to '\0'.
- */
-char *
-vips_strncpy(char *dest, const char *src, int n)
-{
-	int i;
-
-	g_assert(n > 0);
-
-	for (i = 0; i < n - 1; i++)
-		if (!(dest[i] = src[i]))
-			break;
-	dest[i] = '\0';
-
-	return dest;
-}
-
-/* Find the rightmost occurrence of needle in haystack.
- */
-char *
-vips_strrstr(const char *haystack, const char *needle)
-{
-	int haystack_len = strlen(haystack);
-	int needle_len = strlen(needle);
-	int i;
-
-	for (i = haystack_len - needle_len; i >= 0; i--)
-		if (strncmp(needle, haystack + i, needle_len) == 0)
-			return (char *) haystack + i;
-
-	return NULL;
-}
-
-/* Test for string b ends string a.
- */
-gboolean
-vips_ispostfix(const char *a, const char *b)
-{
-	int m = strlen(a);
-	int n = strlen(b);
-
-	if (n > m)
-		return FALSE;
-
-	return strcmp(a + m - n, b) == 0;
-}
-
 /* Case-insensitive test for string b ends string a. ASCII strings only.
  */
 gboolean
@@ -310,7 +261,8 @@ vips_iscasepostfix(const char *a, const char *b)
 }
 
 /* Test for string a starts string b. a is a known-good string, b may be
- * random data.
+ * random data. Use g_str_has_prefix() when both strings are non-NULL and
+ * NULL-terminated.
  */
 gboolean
 vips_isprefix(const char *a, const char *b)
@@ -453,51 +405,6 @@ vips_break_token(char *str, const char *brk)
 	return p;
 }
 
-/* Wrapper over (v)snprintf() ... missing on old systems.
- */
-int
-vips_vsnprintf(char *str, size_t size, const char *format, va_list ap)
-{
-#ifdef HAVE_VSNPRINTF
-	return vsnprintf(str, size, format, ap);
-#else  /*HAVE_VSNPRINTF*/
-	/* Bleurg!
-	 */
-	int n;
-	static char buf[MAX_BUF];
-
-	/* We can't return an error code, we may already have trashed the
-	 * stack. We must stop immediately.
-	 */
-	if (size > MAX_BUF)
-		vips_error_exit("panic: buffer overflow "
-						"(request to write %lu bytes to buffer of %d bytes)",
-			(unsigned long) size, MAX_BUF);
-	n = vsprintf(buf, format, ap);
-	if (n > MAX_BUF)
-		vips_error_exit("panic: buffer overflow "
-						"(%d bytes written to buffer of %d bytes)",
-			n, MAX_BUF);
-
-	vips_strncpy(str, buf, size);
-
-	return n;
-#endif /*HAVE_VSNPRINTF*/
-}
-
-int
-vips_snprintf(char *str, size_t size, const char *format, ...)
-{
-	va_list ap;
-	int n;
-
-	va_start(ap, format);
-	n = vips_vsnprintf(str, size, format, ap);
-	va_end(ap);
-
-	return n;
-}
-
 /* Does a filename have one of a set of suffixes. Ignore case and any trailing
  * options.
  */
@@ -558,11 +465,16 @@ int
 vips__write(int fd, const void *buf, size_t count)
 {
 	do {
-		size_t nwritten = write(fd, buf, count);
+		// write() uses int not size_t on windows, so we need to chunk
+		// ... max 1gb, why not
+		int chunk_size = VIPS_MIN(1024 * 1024 * 1024, count);
+		gint64 nwritten = write(fd, buf, chunk_size);
 
-		if (nwritten == (size_t) -1) {
-			vips_error_system(errno, "vips__write",
-				"%s", _("write failed"));
+		/* n == 0 isn't strictly an error, but we treat it as
+		 * one to make sure we don't get stuck in this loop.
+		 */
+		if (nwritten <= 0) {
+			vips_error_system(errno, "vips__write", "%s", _("write failed"));
 			return -1;
 		}
 
@@ -747,8 +659,7 @@ vips__file_read(FILE *fp, const char *filename, size_t *length_out)
 	if (len > 1024 * 1024 * 1024) {
 		/* Over a gb? Seems crazy!
 		 */
-		vips_error("vips__file_read",
-			_("\"%s\" too long"), filename);
+		vips_error("vips__file_read", _("\"%s\" too long"), filename);
 		return NULL;
 	}
 
@@ -770,8 +681,7 @@ vips__file_read(FILE *fp, const char *filename, size_t *length_out)
 			if (size > 1024 * 1024 * 1024 ||
 				!(str2 = realloc(str, size))) {
 				free(str);
-				vips_error("vips__file_read",
-					"%s", _("out of memory"));
+				vips_error("vips__file_read", "%s", _("out of memory"));
 				return NULL;
 			}
 			str = str2;
@@ -779,8 +689,7 @@ vips__file_read(FILE *fp, const char *filename, size_t *length_out)
 			/* -1 to allow space for an extra NULL we add later.
 			 */
 			read = fread(str + len, sizeof(char),
-				(size - len - 1) / sizeof(char),
-				fp);
+				(size - len - 1) / sizeof(char), fp);
 			len += read;
 		} while (!feof(fp));
 
@@ -798,8 +707,7 @@ vips__file_read(FILE *fp, const char *filename, size_t *length_out)
 		if (read != (size_t) len) {
 			g_free(str);
 			vips_error("vips__file_read",
-				_("error reading from file \"%s\""),
-				filename);
+				_("error reading from file \"%s\""), filename);
 			return NULL;
 		}
 	}
@@ -1187,7 +1095,7 @@ vips_mkdirf(const char *name, ...)
 	if (g_mkdir(path, 0755)) {
 		vips_error("mkdirf",
 			_("unable to create directory \"%s\", %s"),
-			path, strerror(errno));
+			path, g_strerror(errno));
 		g_free(path);
 		return -1;
 	}
@@ -1211,7 +1119,7 @@ vips_rmdirf(const char *name, ...)
 	if (g_rmdir(path)) {
 		vips_error("rmdir",
 			_("unable to remove directory \"%s\", %s"),
-			path, strerror(errno));
+			path, g_strerror(errno));
 		g_free(path);
 		return -1;
 	}
@@ -1228,24 +1136,13 @@ vips_rename(const char *old_name, const char *new_name)
 	if (g_rename(old_name, new_name)) {
 		vips_error("rename",
 			_("unable to rename file \"%s\" as \"%s\", %s"),
-			old_name, new_name, strerror(errno));
+			old_name, new_name, g_strerror(errno));
 		return -1;
 	}
 
 	return 0;
 }
 
-/* Chop off any trailing whitespace.
- */
-void
-vips__chomp(char *str)
-{
-	char *p;
-
-	for (p = str + strlen(str); p > str && isspace(p[-1]); p--)
-		p[-1] = '\0';
-}
-
 /* Break a command-line argument into tokens separated by whitespace.
  *
  * Strings can't be adjacent, so "hello world" (without quotes) is a single
@@ -1260,7 +1157,11 @@ vips__token_get(const char *p, VipsToken *token, char *string, int size)
 	const char *q;
 	int ch;
 	int n;
-	int i;
+
+	/* string return defaults to "".
+	 */
+	if (size > 0)
+		string[0] = '\0';
 
 	/* Parse this token with p.
 	 */
@@ -1296,61 +1197,57 @@ vips__token_get(const char *p, VipsToken *token, char *string, int size)
 
 	case '"':
 	case '\'':
-		/* Parse a quoted string. Copy up to ", interpret any \",
-		 * error if no closing ".
+		/* Parse a quoted string. Copy up to " or end of string, interpret
+		 * any \",
 		 */
 		*token = VIPS_TOKEN_STRING;
 
 		do {
-			/* Number of characters until the next quote
-			 * character or end of string.
+			/* Move q to the next matching quote, or the end of the string.
 			 */
-			if ((q = strchr(p + 1, ch)))
-				n = q - p + 1;
-			else
-				n = strlen(p + 1);
+			if (!(q = strchr(p + 1, ch)))
+				q = p + strlen(p);
 
-			/* How much can we copy to the buffer?
-			 */
-			i = VIPS_MIN(n, size);
-			vips_strncpy(string, p + 1, i);
+			// number of characters we copy to the output
+			n = VIPS_MIN(q - p - 1, size - 1);
+			g_strlcpy(string, p + 1, n + 1);
 
 			/* We might have stopped at an escaped quote. If the
-			 * string was not truncated, swap the preceding
-			 * backslash for a quote.
+			 * char before the end is a backslash, swap it for a quote.
 			 */
-			if (p[n + 1] == ch && p[n] == '\\' && i == n)
-				string[i - 1] = ch;
+			if (q[-1] == '\\')
+				string[n - 1] = ch;
 
-			string += i;
-			size -= i;
-			p += n + 1;
+			string += n;
+			size -= n;
+			p = q;
 		} while (p[0] && p[-1] == '\\');
 
-		p += 1;
+		// step over the terminating quote, if we hit one
+		if (p[0] == ch)
+			p += 1;
 
 		break;
 
 	default:
-		/* It's an unquoted string: read up to the next non-string
-		 * character. We don't allow two strings next to each other,
-		 * so the next break must be brackets, equals, comma.
+		/* It's an unquoted string: read up to the next non-string character.
+		 * We don't allow two strings next to each other, so the next break
+		 * must be brackets, equals, comma.
 		 */
 		*token = VIPS_TOKEN_STRING;
 		q = p + strcspn(p, "[]=,");
 
-		i = VIPS_MIN(q - p, size);
-		vips_strncpy(string, p, i + 1);
+		n = VIPS_MIN(q - p, size);
+		g_strlcpy(string, p, n + 1);
 		p = q;
 
-		/* We remove leading whitespace, so we trim trailing
-		 * whitespace from unquoted strings too. Only if the string
-		 * hasn't been truncated.
+		/* We remove leading whitespace, so we trim trailing whitespace from
+		 * unquoted strings too. Only if the string hasn't been truncated.
 		 */
-		if (i != size)
-			while (i > 0 && isspace(string[i - 1])) {
-				string[i - 1] = '\0';
-				i--;
+		if (n != size)
+			while (n > 0 && g_ascii_isspace(string[n - 1])) {
+				string[n - 1] = '\0';
+				n--;
 			}
 
 		break;
@@ -1438,7 +1335,7 @@ vips__token_segment(const char *p, VipsToken *token,
 		} while (!(sub_token == VIPS_TOKEN_RIGHT && depth == 0));
 
 		i = VIPS_MIN(q - p, size);
-		vips_strncpy(string, p, i + 1);
+		g_strlcpy(string, p, i + 1);
 	}
 
 	return q;
@@ -1542,13 +1439,13 @@ vips__filename_split8(const char *name, char *filename, char *option_string)
 {
 	char *p;
 
-	vips_strncpy(filename, name, VIPS_PATH_MAX);
+	g_strlcpy(filename, name, VIPS_PATH_MAX);
 	if ((p = (char *) vips__find_rightmost_brackets(filename))) {
-		vips_strncpy(option_string, p, VIPS_PATH_MAX);
+		g_strlcpy(option_string, p, VIPS_PATH_MAX);
 		*p = '\0';
 	}
 	else
-		vips_strncpy(option_string, "", VIPS_PATH_MAX);
+		g_strlcpy(option_string, "", VIPS_PATH_MAX);
 }
 
 /* True if an int is a power of two ... 1, 2, 4, 8, 16, 32, etc. Do with just
@@ -1634,9 +1531,9 @@ vips__temp_name(const char *format)
 
 	int serial = g_atomic_int_add(&global_serial, 1);
 
-	vips_snprintf(file, FILENAME_MAX, "vips-%d-%u",
+	g_snprintf(file, FILENAME_MAX, "vips-%d-%u",
 		serial, g_random_int());
-	vips_snprintf(file2, FILENAME_MAX, format, file);
+	g_snprintf(file2, FILENAME_MAX, format, file);
 	name = g_build_filename(vips__temp_dir(), file2, NULL);
 
 	/* We could use something like g_mkstemp() to guarantee uniqueness
@@ -1664,7 +1561,7 @@ vips__change_suffix(const char *name, char *out, int mx,
 
 	/* Copy start string.
 	 */
-	vips_strncpy(out, name, mx);
+	g_strlcpy(out, name, mx);
 
 	/* Drop all matching suffixes.
 	 */
@@ -1687,7 +1584,7 @@ vips__change_suffix(const char *name, char *out, int mx,
 	/* Add new suffix.
 	 */
 	len = strlen(out);
-	vips_strncpy(out + len, new, mx - len);
+	g_strlcpy(out + len, new, mx - len);
 }
 
 typedef struct {
@@ -1701,28 +1598,26 @@ vips__parse_size(const char *size_string)
 	static Unit units[] = {
 		{ 'k', 1024 },
 		{ 'm', 1024 * 1024 },
-		{ 'g', 1024 * 1024 * 1024 }
+		{ 'g', 1024 * 1024 * 1024 },
+		{ 'b', 1024 * 1024 * 1024 }
 	};
 
 	guint64 size;
 	int n;
-	int i;
 	char *unit;
 
 	/* An easy way to alloc a buffer large enough.
 	 */
 	unit = g_strdup(size_string);
-	n = sscanf(size_string, "%d %s", &i, unit);
-	size = i;
-	if (n > 1) {
-		int j;
 
-		for (j = 0; j < VIPS_NUMBER(units); j++)
+	n = sscanf(size_string, "%" G_GUINT64_FORMAT " %s", &size, unit);
+	if (n > 1)
+		for (int j = 0; j < VIPS_NUMBER(units); j++)
 			if (tolower(unit[0]) == units[j].unit) {
 				size *= units[j].multiplier;
 				break;
 			}
-	}
+
 	g_free(unit);
 
 	VIPS_DEBUG_MSG("parse_size: parsed \"%s\" as %" G_GUINT64_FORMAT "\n",
@@ -1816,7 +1711,7 @@ vips_flags_from_nick(const char *domain, GType type, const char *nick)
 	/* It can be a list of nicks, in which case we OR the bits together.
 	 */
 	i = 0;
-	vips_strncpy(str, nick, sizeof(str));
+	g_strlcpy(str, nick, sizeof(str));
 	for (p = str; (q = vips_break_token(p, "\t;:|, ")); p = q) {
 		if ((flags_value = g_flags_get_value_by_name(gflags, p)) ||
 			(flags_value = g_flags_get_value_by_nick(gflags, p)))
@@ -1854,10 +1749,10 @@ vips__substitute(char *buf, size_t len, char *sub)
 	sub_start = NULL;
 	sub_end = NULL;
 	for (p = buf; (p = strchr(p, '%')); p++)
-		if (isdigit(p[1])) {
+		if (g_ascii_isdigit(p[1])) {
 			char *q;
 
-			for (q = p + 1; isdigit(*q); q++)
+			for (q = p + 1; g_ascii_isdigit(*q); q++)
 				;
 			if (q[0] == 's') {
 				int n;
@@ -2065,7 +1960,7 @@ vips_strtod(const char *str, double *out)
 	 * a number and getting zero.
 	 */
 	for (p = str; *p; p++)
-		if (isdigit(*p))
+		if (g_ascii_isdigit(*p))
 			break;
 	if (!*p)
 		return -1;
