@@ -94,6 +94,7 @@ typedef struct {
 	int r;	/* Set previous result in this var */
 	int d1; /* The destination var */
 
+	int n_const;
 	int n_scanline;
 
 	/* The associated line corresponding to the scanline.
@@ -149,10 +150,9 @@ typedef struct {
 	VipsMorph *morph;
 	VipsRegion *ir; /* Input region */
 
-	int *soff; /* Offsets we check for set */
-	int ss;	   /* ... and number we check for set */
-	guint8 *coff; /* Offsets we check for clear */
-	int cs;	   /* ... and number we check for clear */
+	int *off;	   /* Offsets for each non-128 matrix element */
+	int nn128;	   /* Number of non-128 mask elements */
+	guint8 *coeff; /* Array of non-128 mask coefficients */
 
 	int last_bpl; /* Avoid recalcing offsets, if we can */
 
@@ -212,10 +212,9 @@ vips_morph_start(VipsImage *out, void *a, void *b)
 	 */
 	seq->morph = morph;
 	seq->ir = NULL;
-	seq->soff = NULL;
-	seq->ss = 0;
-	seq->coff = NULL;
-	seq->cs = 0;
+	seq->off = NULL;
+	seq->nn128 = 0;
+	seq->coeff = NULL;
 	seq->last_bpl = -1;
 #ifdef HAVE_ORC
 	seq->t1 = NULL;
@@ -224,11 +223,11 @@ vips_morph_start(VipsImage *out, void *a, void *b)
 
 	seq->ir = vips_region_new(in);
 
-	seq->soff = VIPS_ARRAY(out, morph->n_point, int);
-	seq->coff = VIPS_ARRAY(out, morph->n_point, guint8);
+	seq->off = VIPS_ARRAY(out, morph->n_point, int);
+	seq->coeff = VIPS_ARRAY(out, morph->n_point, guint8);
 
-	if (!seq->soff ||
-		!seq->coff) {
+	if (!seq->off ||
+		!seq->coeff) {
 		vips_morph_stop(seq, in, morph);
 		return NULL;
 	}
@@ -263,13 +262,8 @@ vips_dilate_vector_gen(VipsRegion *out_region,
 	VipsImage *M = morph->M;
 	VipsRegion *ir = seq->ir;
 
-	/* Offsets for each non-128 matrix element.
-	 */
-	int *soff = seq->soff;
-
-	/* Array of non-128 mask coefficients.
-	 */
-	guint8 *coff = seq->coff;
+	int *off = seq->off;
+	guint8 *coeff = seq->coeff;
 
 	VipsRect *r = &out_region->valid;
 	int sz = VIPS_REGION_N_ELEMENTS(out_region);
@@ -298,9 +292,7 @@ vips_dilate_vector_gen(VipsRegion *out_region,
 	if (seq->last_bpl != VIPS_REGION_LSKIP(ir)) {
 		seq->last_bpl = VIPS_REGION_LSKIP(ir);
 
-		/* Number of non-128 mask elements.
-		 */
-		seq->ss = 0;
+		seq->nn128 = 0;
 		for (t = morph->coeff, y = 0; y < M->Ysize; y++)
 			for (x = 0; x < M->Xsize; x++, t++) {
 				/* Exclude don't-care elements.
@@ -308,19 +300,18 @@ vips_dilate_vector_gen(VipsRegion *out_region,
 				if (*t == 128)
 					continue;
 
-				soff[seq->ss] =
-					VIPS_REGION_ADDR(ir,
-						x + r->left, y + r->top) -
+				off[seq->nn128] =
+					VIPS_REGION_ADDR(ir, x + r->left, y + r->top) -
 					VIPS_REGION_ADDR(ir, r->left, r->top);
-				coff[seq->ss] = *t;
-				seq->ss++;
+				coeff[seq->nn128] = *t;
+				seq->nn128++;
 			}
 	}
 
 	VIPS_GATE_START("vips_dilate_vector_gen: work");
 
 	vips_dilate_uchar_hwy(out_region, ir, r,
-		sz, seq->ss, soff, coff);
+		sz, seq->nn128, off, coeff);
 
 	VIPS_GATE_STOP("vips_dilate_vector_gen: work");
 
@@ -338,13 +329,8 @@ vips_erode_vector_gen(VipsRegion *out_region,
 	VipsImage *M = morph->M;
 	VipsRegion *ir = seq->ir;
 
-	/* Offsets for each non-128 matrix element.
-	 */
-	int *soff = seq->soff;
-
-	/* Array of non-128 mask coefficients.
-	 */
-	guint8 *coff = seq->coff;
+	int *off = seq->off;
+	guint8 *coeff = seq->coeff;
 
 	VipsRect *r = &out_region->valid;
 	int sz = VIPS_REGION_N_ELEMENTS(out_region);
@@ -373,9 +359,7 @@ vips_erode_vector_gen(VipsRegion *out_region,
 	if (seq->last_bpl != VIPS_REGION_LSKIP(ir)) {
 		seq->last_bpl = VIPS_REGION_LSKIP(ir);
 
-		/* Number of non-128 mask elements.
-		 */
-		seq->ss = 0;
+		seq->nn128 = 0;
 		for (t = morph->coeff, y = 0; y < M->Ysize; y++)
 			for (x = 0; x < M->Xsize; x++, t++) {
 				/* Exclude don't-care elements.
@@ -383,19 +367,18 @@ vips_erode_vector_gen(VipsRegion *out_region,
 				if (*t == 128)
 					continue;
 
-				soff[seq->ss] =
-					VIPS_REGION_ADDR(ir,
-						x + r->left, y + r->top) -
+				off[seq->nn128] =
+					VIPS_REGION_ADDR(ir, x + r->left, y + r->top) -
 					VIPS_REGION_ADDR(ir, r->left, r->top);
-				coff[seq->ss] = *t;
-				seq->ss++;
+				coeff[seq->nn128] = *t;
+				seq->nn128++;
 			}
 	}
 
 	VIPS_GATE_START("vips_erode_vector_gen: work");
 
 	vips_erode_uchar_hwy(out_region, ir, r,
-		sz, seq->ss, soff, coff);
+		sz, seq->nn128, off, coeff);
 
 	VIPS_GATE_STOP("vips_erode_vector_gen: work");
 
@@ -444,6 +427,7 @@ vips_morph_compile_section(VipsMorph *morph, Pass *pass, gboolean first_pass)
 
 	CONST("zero", 0, 1);
 	CONST("one", 255, 1);
+	pass->n_const += 2;
 
 	/* Init the sum. If this is the first pass, it's a constant. If this
 	 * is a later pass, we have to init the sum from the result
@@ -483,8 +467,10 @@ vips_morph_compile_section(VipsMorph *morph, Pass *pass, gboolean first_pass)
 		 */
 		if (x > 0) {
 			g_snprintf(offset, 256, "c%db", x);
-			if (orc_program_find_var_by_name(p, offset) == -1)
+			if (orc_program_find_var_by_name(p, offset) == -1) {
 				CONST(offset, morphology->in->Bands * x, 1);
+				pass->n_const++;
+			}
 			ASM3("loadoffb", "value", source, offset);
 		}
 		else
@@ -511,6 +497,12 @@ vips_morph_compile_section(VipsMorph *morph, Pass *pass, gboolean first_pass)
 				ASM3("andb", "sum", "sum", "value");
 		}
 
+		/* orc allows up to 8 constants, so break early once we
+		 * approach this limit.
+		 */
+		if (pass->n_const >= 7 /*ORC_MAX_CONST_VARS - 1*/)
+			break;
+
 		/* You can have 8 sources, and pass->r counts as one of them,
 		 * so +1 there.
 		 */
@@ -571,6 +563,7 @@ vips_morph_compile(VipsMorph *morph)
 		pass->first = i;
 		pass->last = i;
 		pass->r = -1;
+		pass->n_const = 0;
 		pass->n_scanline = 0;
 
 		if (vips_morph_compile_section(morph, pass, morph->n_pass == 1))
@@ -667,8 +660,8 @@ vips_dilate_gen(VipsRegion *out_region,
 	VipsImage *M = morph->M;
 	VipsRegion *ir = seq->ir;
 
-	int *soff = seq->soff;
-	guint8 *coff = seq->coff;
+	int *off = seq->off;
+	guint8 *coeff = seq->coeff;
 
 	VipsRect *r = &out_region->valid;
 	int le = r->left;
@@ -701,37 +694,24 @@ vips_dilate_gen(VipsRegion *out_region,
 	if (seq->last_bpl != VIPS_REGION_LSKIP(ir)) {
 		seq->last_bpl = VIPS_REGION_LSKIP(ir);
 
-		seq->ss = 0;
-		seq->cs = 0;
+		seq->nn128 = 0;
 		for (t = morph->coeff, y = 0; y < M->Ysize; y++)
-			for (x = 0; x < M->Xsize; x++, t++)
-				switch (*t) {
-				case 255:
-					soff[seq->ss++] =
-						VIPS_REGION_ADDR(ir,
-							x + le, y + to) -
-						VIPS_REGION_ADDR(ir, le, to);
-					break;
+			for (x = 0; x < M->Xsize; x++, t++) {
+				/* Exclude don't-care elements.
+				 */
+				if (*t == 128)
+					continue;
 
-				case 128:
-					break;
-
-				case 0:
-					coff[seq->cs++] =
-						VIPS_REGION_ADDR(ir,
-							x + le, y + to) -
-						VIPS_REGION_ADDR(ir, le, to);
-					break;
-
-				default:
-					g_assert_not_reached();
-				}
+				off[seq->nn128] =
+					VIPS_REGION_ADDR(ir, x + le, y + to) -
+					VIPS_REGION_ADDR(ir, le, to);
+				coeff[seq->nn128] = *t;
+				seq->nn128++;
+			}
 	}
 
 	VIPS_GATE_START("vips_dilate_gen: work");
 
-	/* Dilate!
-	 */
 	for (y = to; y < bo; y++) {
 		VipsPel *p = VIPS_REGION_ADDR(ir, le, y);
 		VipsPel *q = VIPS_REGION_ADDR(out_region, le, y);
@@ -739,28 +719,11 @@ vips_dilate_gen(VipsRegion *out_region,
 		/* Loop along line.
 		 */
 		for (x = 0; x < sz; x++, q++, p++) {
-			/* Search for a hit on the set list.
+			/* Dilate!
 			 */
 			result = 0;
-			for (i = 0; i < seq->ss; i++)
-				if (p[soff[i]]) {
-					/* Found a match!
-					 */
-					result = 255;
-					break;
-				}
-
-			/* No set pixels ... search for a hit in the clear
-			 * pixels.
-			 */
-			if (!result)
-				for (i = 0; i < seq->cs; i++)
-					if (!p[coff[i]]) {
-						/* Found a match!
-						 */
-						result = 255;
-						break;
-					}
+			for (i = 0; i < seq->nn128; i++)
+				result |= !coeff[i] ? ~p[off[i]] : p[off[i]];
 
 			*q = result;
 		}
@@ -784,8 +747,8 @@ vips_erode_gen(VipsRegion *out_region,
 	VipsImage *M = morph->M;
 	VipsRegion *ir = seq->ir;
 
-	int *soff = seq->soff;
-	guint8 *coff = seq->coff;
+	int *off = seq->off;
+	guint8 *coeff = seq->coeff;
 
 	VipsRect *r = &out_region->valid;
 	int le = r->left;
@@ -818,37 +781,24 @@ vips_erode_gen(VipsRegion *out_region,
 	if (seq->last_bpl != VIPS_REGION_LSKIP(ir)) {
 		seq->last_bpl = VIPS_REGION_LSKIP(ir);
 
-		seq->ss = 0;
-		seq->cs = 0;
+		seq->nn128 = 0;
 		for (t = morph->coeff, y = 0; y < M->Ysize; y++)
-			for (x = 0; x < M->Xsize; x++, t++)
-				switch (*t) {
-				case 255:
-					soff[seq->ss++] =
-						VIPS_REGION_ADDR(ir,
-							x + le, y + to) -
-						VIPS_REGION_ADDR(ir, le, to);
-					break;
+			for (x = 0; x < M->Xsize; x++, t++) {
+				/* Exclude don't-care elements.
+				 */
+				if (*t == 128)
+					continue;
 
-				case 128:
-					break;
-
-				case 0:
-					coff[seq->cs++] =
-						VIPS_REGION_ADDR(ir,
-							x + le, y + to) -
-						VIPS_REGION_ADDR(ir, le, to);
-					break;
-
-				default:
-					g_assert_not_reached();
-				}
+				off[seq->nn128] =
+					VIPS_REGION_ADDR(ir, x + le, y + to) -
+					VIPS_REGION_ADDR(ir, le, to);
+				coeff[seq->nn128] = *t;
+				seq->nn128++;
+			}
 	}
 
 	VIPS_GATE_START("vips_erode_gen: work");
 
-	/* Erode!
-	 */
 	for (y = to; y < bo; y++) {
 		VipsPel *p = VIPS_REGION_ADDR(ir, le, y);
 		VipsPel *q = VIPS_REGION_ADDR(out_region, le, y);
@@ -856,25 +806,11 @@ vips_erode_gen(VipsRegion *out_region,
 		/* Loop along line.
 		 */
 		for (x = 0; x < sz; x++, q++, p++) {
-			/* Check all set pixels are set.
+			/* Erode!
 			 */
 			result = 255;
-			for (i = 0; i < seq->ss; i++)
-				if (!p[soff[i]]) {
-					/* Found a mismatch!
-					 */
-					result = 0;
-					break;
-				}
-
-			/* Check all clear pixels are clear.
-			 */
-			if (result)
-				for (i = 0; i < seq->cs; i++)
-					if (p[coff[i]]) {
-						result = 0;
-						break;
-					}
+			for (i = 0; i < seq->nn128; i++)
+				result &= !coeff[i] ? ~p[off[i]] : p[off[i]];
 
 			*q = result;
 		}
@@ -950,7 +886,7 @@ vips_morph_build(VipsObject *object)
 				coeff[i]);
 			return -1;
 		}
-		morph->coeff[i] = coeff[i];
+		morph->coeff[i] = (guint8) coeff[i];
 	}
 
 	/* Try to make a vector path.
