@@ -8,21 +8,21 @@
  * @(#) Results are saved in the structure points
  * @(#) The function expects the following valid data in points:
  * @(#) deltax, deltay, nopoints, halfcorsize, halfareasize
- * @(#) and fills in the memebers:
+ * @(#) and fills in the members:
  * @(#) x, y_reference[], contrast and x,y_secondary[],
  * @(#) based on deltax and deltay
  * @(#) Input image should are either memory mapped or in a buffer.
  * @(#) To make the calculation faster set FACTOR to 1, 2 or 3
  * @(#)  Calculations are based on bandno only.
- * @(#)  The function uses functions im_calculate_contrast() 
- * @(#) which is in im_lrcalcon()
+ * @(#)  The function uses functions vips__find_best_contrast()
+ * @(#) which is in vips_lrcalcon()
  * @(#)
- * @(#) int im_tbcalcon( ref, sec, bandno, points )
- * @(#) IMAGE *ref, *sec;
+ * @(#) int vips_tbcalcon(ref, sec, bandno, points)
+ * @(#) VipsImage *ref, *sec;
  * @(#) int bandno;
- * @(#) TIE_POINTS *points; 	see mosaic.h
- * @(#) 
- * @(#) Returns 0 on sucess  and -1 on error.
+ * @(#) TiePoints *points; 	see mosaic.h
+ * @(#)
+ * @(#) Returns 0 on success  and -1 on error.
  *
  * Copyright: 1990, N. Dessipris.
  *
@@ -35,39 +35,41 @@
  * 12/7/95 JC
  *	- reworked
  *	- what a lot of horrible old code there was too
+ * 18/6/20 kleisauke
+ * 	- convert to vips8
  */
 
 /*
 
-    This file is part of VIPS.
-    
-    VIPS is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+	This file is part of VIPS.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
+	VIPS is free software; you can redistribute it and/or modify
+	it under the terms of the GNU Lesser General Public License as published by
+	the Free Software Foundation; either version 2 of the License, or
+	(at your option) any later version.
 
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA
+	This program is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	GNU Lesser General Public License for more details.
+
+	You should have received a copy of the GNU Lesser General Public License
+	along with this program; if not, write to the Free Software
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+	02110-1301  USA
 
  */
 
 /*
 
-    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
+	These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
 
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif /*HAVE_CONFIG_H*/
-#include <vips/intl.h>
+#include <glib/gi18n-lib.h>
 
 #include <stdio.h>
 #include <math.h>
@@ -77,8 +79,8 @@
 
 #include "pmosaicing.h"
 
-int 
-im__tbcalcon( IMAGE *ref, TIE_POINTS *points )
+int
+vips__tbcalcon(VipsImage *ref, TiePoints *points)
 {
 	/* Geometry: border we must leave around each area.
 	 */
@@ -93,15 +95,15 @@ im__tbcalcon( IMAGE *ref, TIE_POINTS *points )
 	const int len = points->nopoints / AREAS;
 
 	int i;
-	Rect area;
+	VipsRect area;
 
 	/* Make sure we can read image.
 	 */
-	if( im_incheck( ref ) )
-		return( -1 );
-	if( ref->Bands != 1 || ref->BandFmt != IM_BANDFMT_UCHAR ) { 
-		im_error( "im__tbcalcon", "%s", _( "help!" ) );
-		return( -1 );
+	if (vips_image_wio_input(ref))
+		return -1;
+	if (ref->Bands != 1 || ref->BandFmt != VIPS_FORMAT_UCHAR) {
+		vips_error("vips__tbcalcon", "%s", _("help!"));
+		return -1;
 	}
 
 	/* Define bits to search for high-contrast areas.
@@ -110,25 +112,25 @@ im__tbcalcon( IMAGE *ref, TIE_POINTS *points )
 	area.height = ref->Ysize;
 	area.left = 0;
 	area.top = 0;
-	im_rect_marginadjust( &area, -border );
+	vips_rect_marginadjust(&area, -border);
 	area.width--;
 	area.height--;
-	if( area.width < 0 || area.height < 0 ) {
-		im_error( "im__tbcalcon", "%s", _( "overlap too small" ) );
-		return( -1 );
+	if (area.width < 0 || area.height < 0) {
+		vips_error("vips__tbcalcon", "%s", _("overlap too small"));
+		return -1;
 	}
 
 	/* Loop over areas, finding points.
 	 */
-	for( i = 0; area.left < ref->Xsize; area.left += awidth, i++ ) 
-		if( im__find_best_contrast( ref, 
-			area.left, area.top, area.width, area.height,
-			points->x_reference + i*len,
-			points->y_reference + i*len,
-			points->contrast + i*len, 
-			len,
-			points->halfcorsize ) )
-				return( -1 );
+	for (i = 0; area.left < ref->Xsize; area.left += awidth, i++)
+		if (vips__find_best_contrast(ref,
+				area.left, area.top, area.width, area.height,
+				points->x_reference + i * len,
+				points->y_reference + i * len,
+				points->contrast + i * len,
+				len,
+				points->halfcorsize))
+			return -1;
 
-	return( 0 );
+	return 0;
 }
